@@ -80,10 +80,11 @@ bool BestPractices::PreCallValidateCreateRenderPass(VkDevice device, const VkRen
             if (access_requires_memory) {
                 skip |= LogPerformanceWarning(
                     "BestPractices-vkCreateRenderPass-image-requires-memory", device, attachment_loc,
-                    "Attachment %u in the VkRenderPass is a multisampled image with %u samples, but it uses loadOp/storeOp "
+                    "Attachment %" PRIu32 " in the VkRenderPass is a multisampled image with %" PRIu32
+                    " samples, but it uses loadOp/storeOp "
                     "which requires accessing data from memory. Multisampled images should always be loadOp = CLEAR or DONT_CARE, "
                     "storeOp = DONT_CARE. This allows the implementation to use lazily allocated memory effectively.",
-                    i, static_cast<uint32_t>(attachment.samples));
+                    i, SampleCountSize(attachment.samples));
             }
         }
     }
@@ -155,9 +156,11 @@ bool BestPractices::ValidateCmdBeginRenderPass(VkCommandBuffer commandBuffer, co
         if (attachment_needs_readback && (VendorCheckEnabled(kBPVendorArm) || VendorCheckEnabled(kBPVendorIMG))) {
             const LogObjectList objlist(commandBuffer, pRenderPassBegin->renderPass);
             skip |= LogPerformanceWarning("BestPractices-vkCmdBeginRenderPass-attachment-needs-readback", objlist, loc,
-                                          "%s %s: Attachment #%u in render pass has begun with VK_ATTACHMENT_LOAD_OP_LOAD.\n"
+                                          "%s %s: Attachment %" PRIu32
+                                          " in render pass has begun with VK_ATTACHMENT_LOAD_OP_LOAD.\n"
                                           "Submitting this renderpass will cause the driver to inject a readback of the attachment "
-                                          "which will copy in total %u pixels (renderArea = "
+                                          "which will copy in total %" PRIu32
+                                          " pixels (renderArea = "
                                           "{ %s }) to the tile buffer.",
                                           VendorSpecificTag(kBPVendorArm), VendorSpecificTag(kBPVendorIMG), att,
                                           pRenderPassBegin->renderArea.extent.width * pRenderPassBegin->renderArea.extent.height,
@@ -401,7 +404,8 @@ bool BestPractices::ValidateCmdEndRenderPass(VkCommandBuffer commandBuffer, cons
             if (untouched_aspects) {
                 skip |= LogPerformanceWarning(
                     "BestPractices-vkCmdEndRenderPass-redundant-attachment-on-tile", commandBuffer, loc,
-                    "%s %s: Render pass was ended, but attachment #%u (format: %s, untouched aspects %s) "
+                    "%s %s: Render pass was ended, but attachment %" PRIu32
+                    " (format: %s, untouched aspects %s) "
                     "was never accessed by a pipeline or clear command. "
                     "On tile-based architectures, LOAD_OP_LOAD and STORE_OP_STORE consume bandwidth and should not be part of the "
                     "render pass if the attachments are not intended to be accessed.",
