@@ -1,6 +1,7 @@
-/* Copyright (c) 2024-2025 The Khronos Group Inc.
- * Copyright (c) 2024-2025 Valve Corporation
- * Copyright (c) 2024-2025 LunarG, Inc.
+/* Copyright (c) 2024-2026 The Khronos Group Inc.
+ * Copyright (c) 2024-2026 Valve Corporation
+ * Copyright (c) 2024-2026 LunarG, Inc.
+ * Modifications Copyright (C) 2025-2026 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,6 +20,7 @@
 #include <vulkan/vulkan_core.h>
 #include <spirv/unified1/spirv.hpp>
 #include "core_validation.h"
+#include "drawdispatch/drawdispatch_vuids.h"
 #include "error_message/error_strings.h"
 #include "generated/dispatch_functions.h"
 #include "state_tracker/device_generated_commands_state.h"
@@ -31,7 +33,10 @@
 #include "state_tracker/cmd_buffer_state.h"
 #include "state_tracker/pipeline_state.h"
 #include "containers/limits.h"
+#include "containers/container_utils.h"
 #include "cc_buffer_address.h"
+#include "utils/assert_utils.h"
+#include "utils/image_utils.h"
 
 static inline bool IsActionCommand(VkIndirectCommandsTokenTypeEXT type) {
     return IsValueIn(
@@ -43,10 +48,10 @@ static inline bool IsActionCommand(VkIndirectCommandsTokenTypeEXT type) {
 }
 
 // Make sure sub_range is contained inside the full_range
-bool PushConstantRangesContained(VkPushConstantRange full_range, VkPushConstantRange sub_range) {
-    const uint32_t start = full_range.offset;
-    const uint32_t end = start + full_range.size;
-    return (start >= sub_range.offset && end <= (sub_range.offset + sub_range.size));
+bool PushConstantRangesContained(VkPushConstantRange sub_range, VkPushConstantRange full_range) {
+    const uint32_t start = sub_range.offset;
+    const uint32_t end = start + sub_range.size;
+    return (start >= full_range.offset && end <= (full_range.offset + full_range.size));
 }
 
 bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
@@ -61,11 +66,10 @@ bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
     auto pipeline_layout_state = Get<vvl::PipelineLayout>(pCreateInfo->pipelineLayout);
     auto* dynamic_layout_create = vku::FindStructInPNextChain<VkPipelineLayoutCreateInfo>(pCreateInfo->pNext);
 
-    const uint32_t kNotFound = vvl::kU32Max;
-    uint32_t execution_set_token_index = kNotFound;
-    uint32_t vertex_buffer_token_index = kNotFound;
-    uint32_t index_buffer_token_index = kNotFound;
-    uint32_t sequence_index_token_index = kNotFound;
+    uint32_t execution_set_token_index = vvl::kNoIndex32;
+    uint32_t vertex_buffer_token_index = vvl::kNoIndex32;
+    uint32_t index_buffer_token_index = vvl::kNoIndex32;
+    uint32_t sequence_index_token_index = vvl::kNoIndex32;
 
     vvl::unordered_map<uint32_t, uint32_t> vertex_binding_unit_unique;
     vvl::unordered_map<uint32_t, VkPushConstantRange> token_ranges;
@@ -84,30 +88,54 @@ bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
 
             if (!dynamic_layout_create && pipeline_layout_state) {
                 const auto& layout_ranges = *pipeline_layout_state->push_constant_ranges_layout;
+                bool stage_found = false;
                 for (const auto& layout_range : layout_ranges) {
-                    if (!PushConstantRangesContained(token_range, layout_range)) {
-                        skip |= LogError("VUID-VkIndirectCommandsPushConstantTokenEXT-updateRange-11132",
-                                         pipeline_layout_state->Handle(), update_range_loc,
-                                         "is %s but the push constant range in "
-                                         "VkIndirectCommandsLayoutCreateInfoEXT::pipelineLayout is %s.",
-                                         string_VkPushConstantRange(token_range).c_str(),
-                                         string_VkPushConstantRange(layout_range).c_str());
+                    if ((token_range.stageFlags & layout_range.stageFlags) != 0) {
+                        stage_found = true;
+                        if (!PushConstantRangesContained(token_range, layout_range)) {
+                            skip |= LogError("VUID-VkIndirectCommandsPushConstantTokenEXT-updateRange-11132",
+                                             pipeline_layout_state->Handle(), update_range_loc,
+                                             "is %s but the push constant range in "
+                                             "VkIndirectCommandsLayoutCreateInfoEXT::pipelineLayout is %s.",
+                                             string_VkPushConstantRange(token_range).c_str(),
+                                             string_VkPushConstantRange(layout_range).c_str());
+                            break;
+                        }
                     }
-                    break;
+                }
+                if (!stage_found) {
+                    skip |= LogError("VUID-VkIndirectCommandsPushConstantTokenEXT-updateRange-11132",
+                                     pipeline_layout_state->Handle(), update_range_loc,
+                                     "is %s but there is no push constant range in "
+                                     "VkIndirectCommandsLayoutCreateInfoEXT::pipelineLayout for stage %s.",
+                                     string_VkPushConstantRange(token_range).c_str(),
+                                     string_VkShaderStageFlags(token_range.stageFlags).c_str());
                 }
 
             } else if (dynamic_layout_create) {
                 // TODO - Because of custom PushConstantRangesId, can't share logic when using dynamicGeneratedPipelineLayout
+                bool stage_found = false;
                 for (uint32_t pc_index = 0; pc_index < dynamic_layout_create->pushConstantRangeCount; pc_index++) {
                     const VkPushConstantRange& layout_range = dynamic_layout_create->pPushConstantRanges[pc_index];
-                    if (!PushConstantRangesContained(token_range, layout_range)) {
-                        skip |= LogError("VUID-VkIndirectCommandsPushConstantTokenEXT-updateRange-11132", device, update_range_loc,
+                    if ((token_range.stageFlags & layout_range.stageFlags) != 0) {
+                        stage_found = true;
+                        if (!PushConstantRangesContained(token_range, layout_range)) {
+                            skip |=
+                                LogError("VUID-VkIndirectCommandsPushConstantTokenEXT-updateRange-11132", device, update_range_loc,
                                          "is %s but the push constant range in "
                                          "VkPipelineLayoutCreateInfo::pPushConstantRanges[%" PRIu32 "] is %s.",
                                          string_VkPushConstantRange(token_range).c_str(), pc_index,
                                          string_VkPushConstantRange(layout_range).c_str());
+                            break;
+                        }
                     }
-                    break;
+                }
+                if (!stage_found) {
+                    skip |= LogError("VUID-VkIndirectCommandsPushConstantTokenEXT-updateRange-11132", device, update_range_loc,
+                                     "is %s but there is no push constant range in "
+                                     "VkPipelineLayoutCreateInfo::pPushConstantRanges for stage %s.",
+                                     string_VkPushConstantRange(token_range).c_str(),
+                                     string_VkShaderStageFlags(token_range.stageFlags).c_str());
                 }
             }
         } else if (token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_VERTEX_BUFFER_EXT) {
@@ -126,7 +154,7 @@ bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
         // Check for duplicate tokens
         if (token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_EXECUTION_SET_EXT) {
             // currently these 2 VUs overlap but can be helpful to catch in different times
-            if (execution_set_token_index == kNotFound) {
+            if (execution_set_token_index == vvl::kNoIndex32) {
                 execution_set_token_index = i;
                 if (i != 0) {
                     skip |= LogError(
@@ -140,7 +168,7 @@ bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
                                  execution_set_token_index);
             }
         } else if (token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_INDEX_BUFFER_EXT) {
-            if (index_buffer_token_index == kNotFound) {
+            if (index_buffer_token_index == vvl::kNoIndex32) {
                 index_buffer_token_index = i;
             } else {
                 skip |= LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11094", device, token_loc.dot(Field::type),
@@ -148,33 +176,40 @@ bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
                                  "] (can only list token once).",
                                  index_buffer_token_index);
             }
-        } else if (token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_SEQUENCE_INDEX_EXT) {
-            if (sequence_index_token_index == kNotFound) {
+        } else if (token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_SEQUENCE_INDEX_EXT ||
+                   token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_PUSH_DATA_SEQUENCE_INDEX_EXT) {
+            if (sequence_index_token_index == vvl::kNoIndex32) {
                 sequence_index_token_index = i;
             } else {
                 skip |= LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11145", device, token_loc.dot(Field::type),
-                                 "is VK_INDIRECT_COMMANDS_TOKEN_TYPE_SEQUENCE_INDEX_EXT but also was pTokens[%" PRIu32
-                                 "] (can only list token once).",
-                                 sequence_index_token_index);
+                                 "is %s and pTokens[%" PRIu32 "] is %s (can only list token once).",
+                                 string_VkIndirectCommandsTokenTypeEXT(token.type), sequence_index_token_index,
+                                 string_VkIndirectCommandsTokenTypeEXT(token.type));
             }
         } else if (token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_VERTEX_BUFFER_EXT) {
             vertex_buffer_token_index = i;
         }
 
+        const bool push_data = token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_PUSH_DATA_EXT ||
+                               token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_PUSH_DATA_SEQUENCE_INDEX_EXT;
         if (token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_PUSH_CONSTANT_EXT ||
-            token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_SEQUENCE_INDEX_EXT) {
-            if (pCreateInfo->pipelineLayout == VK_NULL_HANDLE) {
-                if (!enabled_features.dynamicGeneratedPipelineLayout) {
-                    skip |= LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11101", device, token_loc.dot(Field::type),
+            token.type == VK_INDIRECT_COMMANDS_TOKEN_TYPE_SEQUENCE_INDEX_EXT || push_data) {
+            if (!push_data) {
+                if (pCreateInfo->pipelineLayout == VK_NULL_HANDLE) {
+                    if (!enabled_features.dynamicGeneratedPipelineLayout) {
+                        skip |=
+                            LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11101", device, token_loc.dot(Field::type),
                                      "is %s, pipelineLayout is VK_NULL_HANDLE, but the "
                                      "dynamicGeneratedPipelineLayout feature was not enabled.",
                                      string_VkIndirectCommandsTokenTypeEXT(token.type));
-                } else if (!dynamic_layout_create) {
-                    skip |= LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11102", device, token_loc.dot(Field::type),
+                    } else if (!dynamic_layout_create) {
+                        skip |=
+                            LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11102", device, token_loc.dot(Field::type),
                                      "is %s, pipelineLayout is VK_NULL_HANDLE, but no "
                                      "there is no VkPipelineLayoutCreateInfo structure attached to the pNext chain.\n%s",
                                      string_VkIndirectCommandsTokenTypeEXT(token.type),
                                      PrintPNextChain(Struct::VkIndirectCommandsLayoutCreateInfoEXT, pCreateInfo->pNext).c_str());
+                    }
                 }
             }
 
@@ -204,7 +239,7 @@ bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
     } else {
         if (!IsValueIn(final_token_type, {VK_INDIRECT_COMMANDS_TOKEN_TYPE_DRAW_INDEXED_EXT,
                                           VK_INDIRECT_COMMANDS_TOKEN_TYPE_DRAW_INDEXED_COUNT_EXT}) &&
-            index_buffer_token_index != kNotFound) {
+            index_buffer_token_index != vvl::kNoIndex32) {
             skip |= LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11095", device,
                              create_info_loc.dot(Field::pTokens, final_token_index).dot(Field::type),
                              "is %s (not an index draw token), but pTokens[%" PRIu32
@@ -214,7 +249,7 @@ bool CoreChecks::PreCallValidateCreateIndirectCommandsLayoutEXT(VkDevice device,
         if (!IsValueIn(final_token_type,
                        {VK_INDIRECT_COMMANDS_TOKEN_TYPE_DRAW_INDEXED_EXT, VK_INDIRECT_COMMANDS_TOKEN_TYPE_DRAW_EXT,
                         VK_INDIRECT_COMMANDS_TOKEN_TYPE_DRAW_INDEXED_COUNT_EXT, VK_INDIRECT_COMMANDS_TOKEN_TYPE_DRAW_COUNT_EXT}) &&
-            vertex_buffer_token_index != kNotFound) {
+            vertex_buffer_token_index != vvl::kNoIndex32) {
             skip |= LogError("VUID-VkIndirectCommandsLayoutCreateInfoEXT-pTokens-11096", device,
                              create_info_loc.dot(Field::pTokens, final_token_index).dot(Field::type),
                              "is %s (not a non-mesh draw token), but pTokens[%" PRIu32
@@ -282,14 +317,17 @@ bool CoreChecks::ValidateIndirectExecutionSetPipelineInfo(const VkIndirectExecut
     }
 
     auto pipeline_layout = initial_pipeline->PipelineLayoutState();
-    ASSERT_AND_RETURN_SKIP(pipeline_layout);
-    for (uint32_t i = 0; i < pipeline_layout->set_layouts.size(); i++) {
-        if (pipeline_layout->set_layouts[i] == nullptr) continue;
-        const auto& bindings = pipeline_layout->set_layouts[i]->GetBindings();
+    if (!pipeline_layout) {
+        assert(initial_pipeline->descriptor_heap_mode);
+        return skip;
+    }
+    for (uint32_t i = 0; i < pipeline_layout->set_layouts.list.size(); i++) {
+        if (pipeline_layout->set_layouts.list[i] == nullptr) continue;
+        const auto& bindings = pipeline_layout->set_layouts.list[i]->GetBindings();
         for (uint32_t j = 0; j < bindings.size(); j++) {
             if (bindings[j].descriptorType == VK_DESCRIPTOR_TYPE_UNIFORM_BUFFER_DYNAMIC ||
                 bindings[j].descriptorType == VK_DESCRIPTOR_TYPE_STORAGE_BUFFER_DYNAMIC) {
-                const LogObjectList objlist(pipeline_layout->Handle(), pipeline_layout->set_layouts[i]->Handle());
+                const LogObjectList objlist(pipeline_layout->Handle(), pipeline_layout->set_layouts.list[i]->Handle());
                 skip |= LogError("VUID-VkIndirectExecutionSetPipelineInfoEXT-initialPipeline-11019", objlist,
                                  pipeline_info_loc.dot(Field::initialPipeline),
                                  "was created with a VkPipelineLayout that contains a descriptor type of %s in pSetLayouts[%" PRIu32
@@ -305,6 +343,8 @@ bool CoreChecks::ValidateIndirectExecutionSetPipelineInfo(const VkIndirectExecut
 bool CoreChecks::ValidateIndirectExecutionSetShaderInfo(const VkIndirectExecutionSetShaderInfoEXT& shader_info,
                                                         const Location& shader_info_loc) const {
     bool skip = false;
+    bool descriptor_flag_same = true;
+    VkShaderCreateFlagsEXT descriptor_flag = 0;
 
     const auto& props = phys_dev_ext_props.device_generated_commands_props;
     vvl::unordered_map<VkShaderStageFlagBits, uint32_t> unique_stages;
@@ -312,11 +352,12 @@ bool CoreChecks::ValidateIndirectExecutionSetShaderInfo(const VkIndirectExecutio
         const VkShaderEXT shader_handle = shader_info.pInitialShaders[i];
         const auto shader_object = Get<vvl::ShaderObject>(shader_handle);
         ASSERT_AND_CONTINUE(shader_object);
-        if ((shader_object->create_info.flags & VK_SHADER_CREATE_INDIRECT_BINDABLE_BIT_EXT) == 0) {
+        const VkShaderCreateFlagsEXT shader_flags = shader_object->create_info.flags;
+        if ((shader_flags & VK_SHADER_CREATE_INDIRECT_BINDABLE_BIT_EXT) == 0) {
             skip |= LogError("VUID-VkIndirectExecutionSetShaderInfoEXT-pInitialShaders-11154", shader_object->Handle(),
                              shader_info_loc.dot(Field::pInitialShaders, i),
                              "is missing VK_SHADER_CREATE_INDIRECT_BINDABLE_BIT_EXT, was created with flags %s.",
-                             string_VkShaderCreateFlagsEXT(shader_object->create_info.flags).c_str());
+                             string_VkShaderCreateFlagsEXT(shader_flags).c_str());
         }
 
         const VkShaderStageFlagBits stage = shader_object->create_info.stage;
@@ -337,6 +378,24 @@ bool CoreChecks::ValidateIndirectExecutionSetShaderInfo(const VkIndirectExecutio
         } else {
             unique_stages[stage] = i;
         }
+
+        if (i == 0) {
+            descriptor_flag = shader_flags & VK_SHADER_CREATE_DESCRIPTOR_HEAP_BIT_EXT;
+        } else if ((shader_flags & VK_SHADER_CREATE_DESCRIPTOR_HEAP_BIT_EXT) != descriptor_flag) {
+            const char* vuid = descriptor_flag ? "VUID-VkIndirectExecutionSetShaderInfoEXT-pInitialShaders-11321"
+                                               : "VUID-VkIndirectExecutionSetShaderInfoEXT-pInitialShaders-11322";
+            skip |= LogError(vuid, shader_handle, shader_info_loc.dot(Field::pInitialShaders, i),
+                             "was created with %s, but pInitialShaders[0] was created with %s.",
+                             string_VkShaderCreateFlagsEXT(shader_flags).c_str(),
+                             string_VkShaderCreateFlagsEXT(descriptor_flag).c_str());
+            descriptor_flag_same = false;
+        }
+    }
+
+    if (descriptor_flag_same && descriptor_flag != 0 && shader_info.pSetLayoutInfos) {
+        const LogObjectList objlist;
+        skip |= LogError("VUID-VkIndirectExecutionSetShaderInfoEXT-pInitialShaders-11323", objlist,
+                         shader_info_loc.dot(Field::pSetLayoutInfos), "(0x%p) is not null", shader_info.pSetLayoutInfos);
     }
 
     return skip;
@@ -466,7 +525,7 @@ bool CoreChecks::ValidateGeneratedCommandsInfo(const vvl::CommandBuffer& cb_stat
         if (generated_commands_info.preprocessSize < mem_reqs.memoryRequirements.size) {
             skip |= LogError(
                 "VUID-VkGeneratedCommandsInfoEXT-preprocessSize-11071", cb_state.Handle(), info_loc.dot(Field::preprocessSize),
-                "(%" PRIu64 ") is less then the size returned from vkGetGeneratedCommandsMemoryRequirementsEXT (%" PRIu64 ").",
+                "(%" PRIu64 ") is less than the size returned from vkGetGeneratedCommandsMemoryRequirementsEXT (%" PRIu64 ").",
                 generated_commands_info.preprocessSize, mem_reqs.memoryRequirements.size);
         }
     }
@@ -478,58 +537,34 @@ bool CoreChecks::ValidateGeneratedCommandsInfo(const vvl::CommandBuffer& cb_stat
             phys_dev_ext_props.device_generated_commands_props.maxIndirectSequenceCount);
     }
 
-    const auto preprocess_buffer_states = GetBuffersByAddress(generated_commands_info.preprocessAddress);
-    if (!preprocess_buffer_states.empty()) {
-        BufferAddressValidation<2> buffer_address_validator = {{{
-            {"VUID-VkGeneratedCommandsInfoEXT-preprocessAddress-11069",
-             [](vvl::Buffer* const buffer_state, std::string* out_error_msg) {
-                 if ((buffer_state->usage & VK_BUFFER_USAGE_2_PREPROCESS_BUFFER_BIT_EXT) == 0) {
-                     if (out_error_msg) {
-                         *out_error_msg += "buffer has usage " + string_VkBufferUsageFlags2(buffer_state->usage);
-                     }
-                     return false;
-                 }
-                 return true;
-             },
-             []() { return "The following buffers are missing VK_BUFFER_USAGE_2_PREPROCESS_BUFFER_BIT_EXT"; }},
-            {"VUID-VkGeneratedCommandsInfoEXT-preprocessAddress-11070",
-             [this](vvl::Buffer* const buffer_state, std::string* out_error_msg) {
-                 return BufferAddressValidation<1>::ValidateMemoryBoundToBuffer(*this, buffer_state, out_error_msg);
-             },
-             []() { return BufferAddressValidation<1>::ValidateMemoryBoundToBufferErrorMsgHeader(); }},
-        }}};
+    {
+        BufferAddressValidation<1> buffer_address_validator = {
+            {{{"VUID-VkGeneratedCommandsInfoEXT-preprocessAddress-11069",
+               [](const vvl::Buffer& buffer_state) {
+                   return (buffer_state.usage & VK_BUFFER_USAGE_2_PREPROCESS_BUFFER_BIT_EXT) == 0;
+               },
+               []() { return "The following buffers are missing VK_BUFFER_USAGE_2_PREPROCESS_BUFFER_BIT_EXT"; },
+               kUsageErrorMsgBuffer}}}};
 
-        skip |= buffer_address_validator.LogErrorsIfNoValidBuffer(
-            *this, preprocess_buffer_states, info_loc.dot(Field::preprocessAddress), LogObjectList(cb_state.Handle()),
-            generated_commands_info.preprocessAddress);
+        skip |= buffer_address_validator.ValidateDeviceAddress(*this, info_loc.dot(Field::preprocessAddress),
+                                                               LogObjectList(cb_state.Handle()),
+                                                               generated_commands_info.preprocessAddress);
     }
 
-    const auto sequence_buffer_states = GetBuffersByAddress(generated_commands_info.sequenceCountAddress);
-    if (!sequence_buffer_states.empty()) {
-        BufferAddressValidation<2> buffer_address_validator = {{{
-            {"VUID-VkGeneratedCommandsInfoEXT-sequenceCountAddress-11072",
-             [](vvl::Buffer* const buffer_state, std::string* out_error_msg) {
-                 if ((buffer_state->usage & VK_BUFFER_USAGE_2_INDIRECT_BUFFER_BIT) == 0) {
-                     if (out_error_msg) {
-                         *out_error_msg += "buffer has usage " + string_VkBufferUsageFlags2(buffer_state->usage);
-                     }
-                     return false;
-                 }
-                 return true;
-             },
-             []() { return "The following buffers are missing VK_BUFFER_USAGE_2_INDIRECT_BUFFER_BIT"; }},
-            {"VUID-VkGeneratedCommandsInfoEXT-sequenceCountAddress-11075",
-             [this](vvl::Buffer* const buffer_state, std::string* out_error_msg) {
-                 return BufferAddressValidation<1>::ValidateMemoryBoundToBuffer(*this, buffer_state, out_error_msg);
-             },
-             []() { return BufferAddressValidation<1>::ValidateMemoryBoundToBufferErrorMsgHeader(); }},
-        }}};
+    {
+        BufferAddressValidation<1> buffer_address_validator = {
+            {{{"VUID-VkGeneratedCommandsInfoEXT-sequenceCountAddress-11072",
+               [](const vvl::Buffer& buffer_state) { return (buffer_state.usage & VK_BUFFER_USAGE_2_INDIRECT_BUFFER_BIT) == 0; },
+               []() { return "The following buffers are missing VK_BUFFER_USAGE_2_INDIRECT_BUFFER_BIT"; }, kUsageErrorMsgBuffer}}}};
 
-        skip |= buffer_address_validator.LogErrorsIfNoValidBuffer(
-            *this, sequence_buffer_states, info_loc.dot(Field::sequenceCountAddress), LogObjectList(cb_state.Handle()),
-            generated_commands_info.sequenceCountAddress);
+        skip |= buffer_address_validator.ValidateDeviceAddress(*this, info_loc.dot(Field::sequenceCountAddress),
+                                                               LogObjectList(cb_state.Handle()),
+                                                               generated_commands_info.sequenceCountAddress);
     }
 
+    skip |= ValidateDeviceAddress(info_loc.dot(Field::indirectAddress), LogObjectList(cb_state.Handle()),
+                                  generated_commands_info.indirectAddress);
+
     return skip;
 }
 
@@ -561,8 +596,9 @@ bool CoreChecks::PreCallValidateCmdExecuteGeneratedCommandsEXT(VkCommandBuffer c
     }
 
     if (cb_state.begin_info_flags & VK_COMMAND_BUFFER_USAGE_SIMULTANEOUS_USE_BIT) {
-        LogError("VUID-vkCmdExecuteGeneratedCommandsEXT-commandBuffer-11143", commandBuffer,
-                 error_obj.location.dot(Field::commandBuffer), "was created with VK_COMMAND_BUFFER_USAGE_SIMULTANEOUS_USE_BIT.");
+        skip |= LogError("VUID-vkCmdExecuteGeneratedCommandsEXT-commandBuffer-11143", commandBuffer,
+                         error_obj.location.dot(Field::commandBuffer),
+                         "was created with VK_COMMAND_BUFFER_USAGE_SIMULTANEOUS_USE_BIT.");
     }
 
     const Location info_loc = error_obj.location.dot(Field::pGeneratedCommandsInfo);
@@ -584,19 +620,10 @@ bool CoreChecks::PreCallValidateCmdExecuteGeneratedCommandsEXT(VkCommandBuffer c
             "was created with VK_INDIRECT_COMMANDS_LAYOUT_USAGE_EXPLICIT_PREPROCESS_BIT_EXT but isPreprocessed is VK_FALSE.");
     }
 
-    if (const vvl::RenderPass* rp_state = cb_state.active_render_pass.get()) {
-        uint32_t view_mask = 0;
-        if (rp_state->UsesDynamicRendering()) {
-            view_mask = rp_state->dynamic_rendering_begin_rendering_info.viewMask;
-        } else {
-            const auto* render_pass_info = rp_state->create_info.ptr();
-            const auto subpass_desc = render_pass_info->pSubpasses[cb_state.GetActiveSubpass()];
-            view_mask = subpass_desc.viewMask;
-        }
-        if (view_mask != 0) {
-            skip |= LogError("VUID-vkCmdExecuteGeneratedCommandsEXT-None-11062", commandBuffer, error_obj.location,
-                             "The active render pass contains a non-zero viewMask (0x%" PRIx32 ").", view_mask);
-        }
+    uint32_t view_mask = cb_state.GetViewMask();
+    if (view_mask != 0) {
+        skip |= LogError("VUID-vkCmdExecuteGeneratedCommandsEXT-None-11062", commandBuffer, error_obj.location,
+                         "The active render pass contains a non-zero viewMask (0x%" PRIx32 ").", view_mask);
     }
 
     if (auto indirect_execution_set = Get<vvl::IndirectExecutionSet>(pGeneratedCommandsInfo->indirectExecutionSet)) {
@@ -623,6 +650,16 @@ bool CoreChecks::PreCallValidateCmdExecuteGeneratedCommandsEXT(VkCommandBuffer c
 
     skip |= ValidateGeneratedCommandsInfo(cb_state, *indirect_commands_layout, *pGeneratedCommandsInfo, isPreprocessed, info_loc);
 
+    // You can only have 1 "action token" so we know there is only a draw or dispatch or traceRay
+    // If a VkIndirectExecutionSetEXT is not used, we can guarantee the pipeline/shaderObject being used.
+    if (pGeneratedCommandsInfo->indirectExecutionSet == VK_NULL_HANDLE) {
+        const VkPipelineBindPoint vk_bind_point = ConvertStageToBindPoint(pGeneratedCommandsInfo->shaderStages);
+        const vvl::BindPoint vvl_bind_point = ConvertToVvlBindPoint(vk_bind_point);
+        const LastBound& last_bound = cb_state.lastBound[vvl_bind_point];
+        const vvl::DrawDispatchVuid& vuid = vvl::GetDrawDispatchVuid(error_obj.location.function);
+        skip |= ValidateActionState(last_bound, vuid);
+    }
+
     return skip;
 }
 
@@ -653,11 +690,11 @@ bool CoreChecks::ValidateGeneratedCommandsInitialShaderState(const vvl::CommandB
     } else if (indirect_execution_set.is_shader_objects) {
         // Shader Objects only has compute or graphics
         if (bind_point == VK_PIPELINE_BIND_POINT_COMPUTE) {
-            if (!last_bound.IsValidShaderBound(ShaderObjectStage::COMPUTE)) {
+            if (!last_bound.IsValidShaderObjectBound(ShaderObjectStage::COMPUTE)) {
                 skip |= LogError(vuid, objlist, cb_loc, "has not had a compute VkShaderEXT bound yet.");
             }
         } else if (bind_point == VK_PIPELINE_BIND_POINT_GRAPHICS) {
-            if (!last_bound.IsAnyGraphicsShaderBound()) {
+            if (!last_bound.IsAnyGraphicsStageBound()) {
                 skip |= LogError(vuid, objlist, cb_loc, "has not had a graphics VkShaderEXT bound yet.");
             }
         }
@@ -674,13 +711,15 @@ bool CoreChecks::ValidatePreprocessGeneratedCommandsStateCommandBuffer(const vvl
                                                                        const Location& loc) const {
     bool skip = false;
 
-    if (state_command_buffer.state == CbState::InvalidComplete || state_command_buffer.state == CbState::InvalidIncomplete) {
+    if (state_command_buffer.state == CbState::InvalidIncomplete) {
         skip |= ReportInvalidCommandBuffer(state_command_buffer, loc.dot(Field::stateCommandBuffer),
                                            "VUID-vkCmdPreprocessGeneratedCommandsEXT-stateCommandBuffer-11138");
-    } else if (CbState::Recording != state_command_buffer.state) {
+    } else if (!IsRecording(state_command_buffer.state)) {
         const LogObjectList objlist(command_buffer.Handle(), state_command_buffer.Handle());
         skip |= LogError("VUID-vkCmdPreprocessGeneratedCommandsEXT-stateCommandBuffer-11138", objlist,
-                         loc.dot(Field::stateCommandBuffer), "is not in a recording state.");
+                         loc.dot(Field::stateCommandBuffer),
+                         "(%s) is not in a recording state. vkBeginCommandBuffer() must first be called.",
+                         FormatHandle(state_command_buffer).c_str());
     }
 
     if (auto indirect_execution_set = Get<vvl::IndirectExecutionSet>(generated_commands_info.indirectExecutionSet)) {
@@ -947,7 +986,7 @@ bool CoreChecks::PreCallValidateUpdateIndirectExecutionSetPipelineEXT(
 
             const auto initial_pipeline_layout = initial_pipeline->PipelineLayoutState();
             const auto update_pipeline_layout = update_pipeline->PipelineLayoutState();
-            if (initial_pipeline_layout && update_pipeline_layout) {
+            if (initial_pipeline_layout && update_pipeline_layout && !initial_pipeline->descriptor_heap_mode) {
                 const uint32_t set_count = (uint32_t)std::min(initial_pipeline_layout->set_compat_ids.size(),
                                                               update_pipeline_layout->set_compat_ids.size());
                 for (uint32_t set = 0; set < set_count; set++) {
@@ -956,7 +995,8 @@ bool CoreChecks::PreCallValidateUpdateIndirectExecutionSetPipelineEXT(
                                               update_pipeline->Handle(), update_pipeline_layout->Handle());
                         skip |= LogError(
                             "VUID-vkUpdateIndirectExecutionSetPipelineEXT-None-11039", objlist, set_write_loc.dot(Field::pipeline),
-                            "%s was created with a layout %s which is not compatible with the initialPipeline layout %s for set "
+                            "%s was created with a layout %s which is not compatible with the initialPipeline "
+                            "layout %s for set "
                             "%" PRIu32 ".\n%s",
                             FormatHandle(update_pipeline->VkHandle()).c_str(),
                             FormatHandle(update_pipeline_layout->VkHandle()).c_str(),
@@ -967,6 +1007,17 @@ bool CoreChecks::PreCallValidateUpdateIndirectExecutionSetPipelineEXT(
                     }
                 }
             }
+            if (initial_pipeline->descriptor_heap_mode != update_pipeline->descriptor_heap_mode) {
+                const LogObjectList objlist(initial_pipeline->Handle(), update_pipeline->Handle());
+                const char* vuid = initial_pipeline->descriptor_heap_mode
+                                       ? "VUID-vkUpdateIndirectExecutionSetPipelineEXT-initialPipeline-11325"
+                                       : "VUID-vkUpdateIndirectExecutionSetPipelineEXT-initialPipeline-11324";
+                skip |= LogError(
+                    vuid, objlist, set_write_loc.dot(Field::pipeline),
+                    "was %screated with VK_PIPELINE_CREATE_2_DESCRIPTOR_HEAP_BIT_EXT, but the initialPipeline was %screated "
+                    "with VK_PIPELINE_CREATE_2_DESCRIPTOR_HEAP_BIT_EXT.",
+                    update_pipeline->descriptor_heap_mode ? "" : "not ", initial_pipeline->descriptor_heap_mode ? "" : "not ");
+            }
         }
     }
 
@@ -988,6 +1039,9 @@ bool CoreChecks::PreCallValidateUpdateIndirectExecutionSetShaderEXT(VkDevice dev
     }
 
     vvl::unordered_map<uint32_t, uint32_t> unique_indexes;
+    const VkShaderEXT init_shader_handle = indirect_execution_set->safe_create_info.info.pShaderInfo->pInitialShaders[0];
+    const auto init_shader_object = Get<vvl::ShaderObject>(init_shader_handle);
+
     for (uint32_t i = 0; i < executionSetWriteCount; i++) {
         const VkWriteIndirectExecutionSetShaderEXT& set_shader = pExecutionSetWrites[i];
         const Location set_write_loc = error_obj.location.dot(Field::pExecutionSetWrites, i);
@@ -1004,7 +1058,7 @@ bool CoreChecks::PreCallValidateUpdateIndirectExecutionSetShaderEXT(VkDevice dev
         if (set_shader.index >= indirect_execution_set->max_shader_count) {
             skip |= LogError("VUID-VkWriteIndirectExecutionSetShaderEXT-index-11031", device, set_write_loc.dot(Field::index),
                              "(%" PRIu32
-                             ") is not less then the sum of VkIndirectExecutionSetShaderInfoEXT::maxShaderCount (%" PRIu32 ").",
+                             ") is not less than the sum of VkIndirectExecutionSetShaderInfoEXT::maxShaderCount (%" PRIu32 ").",
                              set_shader.index, indirect_execution_set->max_shader_count);
         }
 
@@ -1092,6 +1146,21 @@ bool CoreChecks::PreCallValidateUpdateIndirectExecutionSetShaderEXT(VkDevice dev
                 }
             }
         }
+        if (indirect_execution_set->safe_create_info.info.pShaderInfo->shaderCount > 0) {
+            if (init_shader_object && update_shader_object &&
+                init_shader_object->descriptor_heap_mode != update_shader_object->descriptor_heap_mode) {
+                const LogObjectList objlist(init_shader_object->Handle(), update_shader_object->Handle());
+                const char* vuid = init_shader_object->descriptor_heap_mode
+                                       ? "VUID-vkUpdateIndirectExecutionSetShaderEXT-pInitialShaders-11327"
+                                       : "VUID-vkUpdateIndirectExecutionSetShaderEXT-pInitialShaders-11326";
+
+                skip |= LogError(vuid, objlist, set_write_loc.dot(Field::shader),
+                                 "was %screated with VK_SHADER_CREATE_DESCRIPTOR_HEAP_BIT_EXT, but pInitialShaders[0] "
+                                 "was %screated with VK_SHADER_CREATE_DESCRIPTOR_HEAP_BIT_EXT.",
+                                 update_shader_object->descriptor_heap_mode ? "" : "not ",
+                                 init_shader_object->descriptor_heap_mode ? "" : "not ");
+            }
+        }
     }
 
     return skip;
