@@ -1,6 +1,6 @@
-/* Copyright (c) 2024-2025 The Khronos Group Inc.
- * Copyright (c) 2024-2025 Valve Corporation
- * Copyright (c) 2024-2025 LunarG, Inc.
+/* Copyright (c) 2024-2026 The Khronos Group Inc.
+ * Copyright (c) 2024-2026 Valve Corporation
+ * Copyright (c) 2024-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,39 +29,58 @@
     }
 }
 
+[[maybe_unused]] static std::string string_AttachmentPointer(const uint32_t *attachment) {
+    if (!attachment) {
+        return "NULL";
+    }
+    return string_Attachment(*attachment);
+}
+
 [[maybe_unused]] static std::string string_VkExtent2D(VkExtent2D extent) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "width = " << extent.width << ", height = " << extent.height;
     return ss.str();
 }
 
 [[maybe_unused]] static std::string string_VkExtent3D(VkExtent3D extent) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "width = " << extent.width << ", height = " << extent.height << ", depth = " << extent.depth;
     return ss.str();
 }
 
+[[maybe_unused]] static std::string string_VkExtentDimensions(VkExtent2D extent) {
+    std::ostringstream ss;
+    ss << extent.width << "x" << extent.height;
+    return ss.str();
+}
+
+[[maybe_unused]] static std::string string_VkExtentDimensions(VkExtent3D extent) {
+    std::ostringstream ss;
+    ss << extent.width << "x" << extent.height << "x" << extent.depth;
+    return ss.str();
+}
+
 [[maybe_unused]] static std::string string_VkOffset2D(VkOffset2D offset) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "x = " << offset.x << ", y = " << offset.y;
     return ss.str();
 }
 
 [[maybe_unused]] static std::string string_VkOffset3D(VkOffset3D offset) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "x = " << offset.x << ", y = " << offset.y << ", z = " << offset.z;
     return ss.str();
 }
 
 [[maybe_unused]] static std::string string_VkRect2D(VkRect2D rect) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "offset = {" << rect.offset.x << ", " << rect.offset.y << "}, extent = {" << rect.extent.width << ", "
        << rect.extent.height << "}";
     return ss.str();
 }
 
 [[maybe_unused]] static std::string string_LevelCount(const VkImageCreateInfo &ci, VkImageSubresourceRange const &range) {
-    std::stringstream ss;
+    std::ostringstream ss;
     if (range.levelCount == VK_REMAINING_MIP_LEVELS) {
         const uint32_t level_count = ci.mipLevels - range.baseMipLevel;
         ss << "VK_REMAINING_MIP_LEVELS [mipLevels (" << ci.mipLevels << ") - baseMipLevel (" << range.baseMipLevel
@@ -73,7 +92,7 @@
 }
 
 [[maybe_unused]] static std::string string_LayerCount(const VkImageCreateInfo &ci, VkImageSubresourceRange const &range) {
-    std::stringstream ss;
+    std::ostringstream ss;
     if (range.layerCount == VK_REMAINING_ARRAY_LAYERS) {
         const uint32_t layer_count = ci.arrayLayers - range.baseArrayLayer;
         ss << "VK_REMAINING_ARRAY_LAYERS [arrayLayers (" << ci.arrayLayers << ") - baseArrayLayer (" << range.baseArrayLayer
@@ -85,7 +104,7 @@
 }
 
 [[maybe_unused]] static std::string string_LayerCount(const VkImageCreateInfo &ci, VkImageSubresourceLayers const &resource) {
-    std::stringstream ss;
+    std::ostringstream ss;
     if (resource.layerCount == VK_REMAINING_ARRAY_LAYERS) {
         const uint32_t layer_count = ci.arrayLayers - resource.baseArrayLayer;
         ss << "VK_REMAINING_ARRAY_LAYERS [arrayLayers (" << ci.arrayLayers << ") - baseArrayLayer (" << resource.baseArrayLayer
@@ -97,21 +116,21 @@
 }
 
 [[maybe_unused]] static std::string string_VkPushConstantRange(VkPushConstantRange range) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "range [" << range.offset << ", " << (range.offset + range.size) << ") for "
        << string_VkShaderStageFlags(range.stageFlags);
     return ss.str();
 }
 
 [[maybe_unused]] static std::string string_VkImageSubresource(VkImageSubresource subresource) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "aspectMask = " << string_VkImageAspectFlags(subresource.aspectMask) << ", mipLevel = " << subresource.mipLevel
        << ", arrayLayer = " << subresource.arrayLayer;
     return ss.str();
 }
 
 [[maybe_unused]] static std::string string_VkImageSubresourceLayers(VkImageSubresourceLayers subresource_layers) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "aspectMask = " << string_VkImageAspectFlags(subresource_layers.aspectMask)
        << ", mipLevel = " << subresource_layers.mipLevel << ", baseArrayLayer = " << subresource_layers.baseArrayLayer
        << ", layerCount = " << subresource_layers.layerCount;
@@ -119,7 +138,7 @@
 }
 
 [[maybe_unused]] static std::string string_VkImageSubresourceRange(VkImageSubresourceRange subresource_range) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "aspectMask = " << string_VkImageAspectFlags(subresource_range.aspectMask)
        << ", baseMipLevel = " << subresource_range.baseMipLevel << ", levelCount = " << subresource_range.levelCount
        << ", baseArrayLayer = " << subresource_range.baseArrayLayer << ", layerCount = " << subresource_range.layerCount;
@@ -127,7 +146,7 @@
 }
 
 [[maybe_unused]] static std::string string_VkComponentMapping(VkComponentMapping components) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "r swizzle = " << string_VkComponentSwizzle(components.r) << "\n";
     ss << "g swizzle = " << string_VkComponentSwizzle(components.g) << "\n";
     ss << "b swizzle = " << string_VkComponentSwizzle(components.b) << "\n";
@@ -139,7 +158,7 @@
 
 // Some VUs use the subset in VkPhysicalDeviceImageFormatInfo2 to refer to an VkImageCreateInfo
 [[maybe_unused]] static std::string string_VkPhysicalDeviceImageFormatInfo2(VkPhysicalDeviceImageFormatInfo2 info) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "format (" << string_VkFormat(info.format) << ")\n";
     ss << "type (" << string_VkImageType(info.type) << ")\n";
     ss << "tiling (" << string_VkImageTiling(info.tiling) << ")\n";
@@ -150,7 +169,7 @@
 
 // Same thing as VkPhysicalDeviceImageFormatInfo2 but given the actual VkImageCreateInfo
 [[maybe_unused]] static std::string string_VkPhysicalDeviceImageFormatInfo2(VkImageCreateInfo info) {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "format (" << string_VkFormat(info.format) << ")\n";
     ss << "type (" << string_VkImageType(info.imageType) << ")\n";
     ss << "tiling (" << string_VkImageTiling(info.tiling) << ")\n";
@@ -159,10 +178,22 @@
     return ss.str();
 }
 
+[[maybe_unused]] static std::string string_VkStencilOpState(VkStencilOpState state) {
+    std::ostringstream ss;
+    ss << " failOp (" << string_VkStencilOp(state.failOp) << ")\n";
+    ss << " passOp (" << string_VkStencilOp(state.passOp) << ")\n";
+    ss << " depthFailOp (" << string_VkStencilOp(state.depthFailOp) << ")\n";
+    ss << " compareOp (" << string_VkCompareOp(state.compareOp) << ")\n";
+    ss << " compareMask (" << state.compareMask << ")\n";
+    ss << " writeMask (" << state.writeMask << ")\n";
+    ss << " reference (" << state.reference << ")\n";
+    return ss.str();
+}
+
 [[maybe_unused]] static std::string string_VkDependencyInfo(const Logger &logger, VkDependencyInfo set_dependency_info,
                                                             VkDependencyInfo dependency_info) {
-    std::stringstream set;
-    std::stringstream wait;
+    std::ostringstream set;
+    std::ostringstream wait;
     if (set_dependency_info.dependencyFlags != dependency_info.dependencyFlags) {
         set << std::string(string_VkDependencyFlags(set_dependency_info.dependencyFlags));
         wait << std::string(string_VkDependencyFlags(dependency_info.dependencyFlags));
@@ -353,3 +384,19 @@
     }
     return "event was set with " + set.str() + " and is being waited on with " + wait.str();
 }
+
+[[maybe_unused]] static std::string string_VkDataGraphPipelineResourceInfoARM(VkDataGraphPipelineResourceInfoARM resource) {
+    std::ostringstream ss;
+    ss << "[descriptorSet " << resource.descriptorSet << ", ";
+    ss << "binding " << resource.binding << ", ";
+    ss << "arrayElement " << resource.arrayElement << "]";
+    return ss.str();
+}
+
+[[maybe_unused]] static std::string string_VkBindHeapInfoEXT(VkBindHeapInfoEXT info) {
+    std::stringstream ss;
+    ss << "heapRange = { address = " << info.heapRange.address << ", size = " << info.heapRange.size << " }, ";
+    ss << "reservedRangeOffset = " << info.reservedRangeOffset << ", ";
+    ss << "reservedRangeSize = " << info.reservedRangeSize << "";
+    return ss.str();
+}
