@@ -1,6 +1,6 @@
-/* Copyright (c) 2018-2025 The Khronos Group Inc.
- * Copyright (c) 2018-2025 Valve Corporation
- * Copyright (c) 2018-2025 LunarG, Inc.
+/* Copyright (c) 2018-2026 The Khronos Group Inc.
+ * Copyright (c) 2018-2026 Valve Corporation
+ * Copyright (c) 2018-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -166,6 +166,7 @@ void CommandBufferSubState::AddCommandErrorLogger(const Location &loc, const Las
 void CommandBufferSubState::ResetCBState(bool should_destroy) {
     // Free or return to cache GPU resources
 
+    on_instrumentation_error_logger_register_functions.clear();
     on_instrumentation_desc_set_update_functions.clear();
     on_instrumentation_desc_buffer_update_functions.clear();
     on_cb_completion_functions.clear();
@@ -343,12 +344,12 @@ void CommandBufferSubState::OnCompletion(VkQueue queue, const std::vector<std::s
                 error_output_buffer_ptr + (glsl::kErrorBufferByteSize - cst::stream_output_data_offset);
 
             uint32_t *error_record_ptr = error_records_start;
-            uint32_t record_size = error_record_ptr[glsl::kHeaderErrorRecordSizeOffset];
+            uint32_t record_size = error_record_ptr[glsl::kHeader_ErrorRecordSizeOffset];
             assert(record_size == glsl::kErrorRecordSize);
 
             while (record_size > 0 && (error_record_ptr + record_size) <= error_records_end) {
                 const uint32_t error_logger_i =
-                    error_record_ptr[glsl::kHeaderActionIdErrorLoggerIdOffset] & glsl::kErrorLoggerIdMask;
+                    error_record_ptr[glsl::kHeader_ActionIdErrorLoggerIdOffset] & glsl::kErrorLoggerId_Mask;
 
                 assert(error_logger_i < cst::indices_count);
                 if (error_logger_i == cst::invalid_index_command) {
@@ -370,7 +371,7 @@ void CommandBufferSubState::OnCompletion(VkQueue queue, const std::vector<std::s
 
                 // Next record
                 error_record_ptr += record_size;
-                record_size = error_record_ptr[glsl::kHeaderErrorRecordSizeOffset];
+                record_size = error_record_ptr[glsl::kHeader_ErrorRecordSizeOffset];
             }
 
             VVL_TracyPlot("GPU-AV errors count", int64_t(total_words / glsl::kErrorRecordSize));
