@@ -1,4 +1,4 @@
-/* Copyright (c) 2024-2025 LunarG, Inc.
+/* Copyright (c) 2024-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -44,7 +44,7 @@ bool Pass::Run() {
     return modified;
 }
 
-const Variable& Pass::GetBuiltinVariable(uint32_t built_in) {
+const Variable& Pass::GetBuiltInVariable(uint32_t built_in) {
     uint32_t variable_id = 0;
     for (const auto& annotation : module_.annotations_) {
         if (annotation->Opcode() == spv::OpDecorate && annotation->Word(2) == spv::DecorationBuiltIn &&
@@ -98,40 +98,40 @@ uint32_t Pass::GetStageInfo(Function& function, const BasicBlock& target_block_i
     if (module_.entry_points_.size() > 1) {
         // For Multi Entry Points it currently a lot of work to scan every function to see where it will be called from
         // For now we will just report it is "unknown" and skip printing that part of the error message
-        stage_info[0] = type_manager_.GetConstantUInt32(glsl::kExecutionModelMultiEntryPoint).Id();
+        stage_info[0] = type_manager_.GetConstantUInt32(glsl::kExecutionModel_MultiEntryPoint).Id();
     } else {
         spv::ExecutionModel execution_model = spv::ExecutionModel(module_.entry_points_.begin()->get()->Operand(0));
 
         // Need to map how GenerateStageMessage() will consume it
         uint32_t normalized_execution_model = execution_model;
         if (execution_model == spv::ExecutionModelTaskNV) {
-            normalized_execution_model = glsl::kExecutionModelTaskNV;
+            normalized_execution_model = glsl::kExecutionModel_TaskNV;
         } else if (execution_model == spv::ExecutionModelMeshNV) {
-            normalized_execution_model = glsl::kExecutionModelMeshNV;
+            normalized_execution_model = glsl::kExecutionModel_MeshNV;
         } else if (execution_model == spv::ExecutionModelRayGenerationKHR) {
-            normalized_execution_model = glsl::kExecutionModelRayGenerationKHR;
+            normalized_execution_model = glsl::kExecutionModel_RayGenerationKHR;
         } else if (execution_model == spv::ExecutionModelIntersectionKHR) {
-            normalized_execution_model = glsl::kExecutionModelIntersectionKHR;
+            normalized_execution_model = glsl::kExecutionModel_IntersectionKHR;
         } else if (execution_model == spv::ExecutionModelAnyHitKHR) {
-            normalized_execution_model = glsl::kExecutionModelAnyHitKHR;
+            normalized_execution_model = glsl::kExecutionModel_AnyHitKHR;
         } else if (execution_model == spv::ExecutionModelClosestHitKHR) {
-            normalized_execution_model = glsl::kExecutionModelClosestHitKHR;
+            normalized_execution_model = glsl::kExecutionModel_ClosestHitKHR;
         } else if (execution_model == spv::ExecutionModelMissKHR) {
-            normalized_execution_model = glsl::kExecutionModelMissKHR;
+            normalized_execution_model = glsl::kExecutionModel_MissKHR;
         } else if (execution_model == spv::ExecutionModelCallableKHR) {
-            normalized_execution_model = glsl::kExecutionModelCallableKHR;
+            normalized_execution_model = glsl::kExecutionModel_CallableKHR;
         } else if (execution_model == spv::ExecutionModelCallableKHR) {
-            normalized_execution_model = glsl::kExecutionModelCallableKHR;
+            normalized_execution_model = glsl::kExecutionModel_CallableKHR;
         } else if (execution_model == spv::ExecutionModelTaskEXT) {
-            normalized_execution_model = glsl::kExecutionModelTaskEXT;
+            normalized_execution_model = glsl::kExecutionModel_TaskEXT;
         } else if (execution_model == spv::ExecutionModelMeshEXT) {
-            normalized_execution_model = glsl::kExecutionModelMeshEXT;
+            normalized_execution_model = glsl::kExecutionModel_MeshEXT;
         }
         stage_info[0] = type_manager_.GetConstantUInt32(normalized_execution_model).Id();
 
         // Gets BuiltIn variable and creates a valid OpLoad of it
         auto create_load = [this, &block, &inst_it](spv::BuiltIn built_in) {
-            const Variable& variable = GetBuiltinVariable(built_in);
+            const Variable& variable = GetBuiltInVariable(built_in);
             const Type* pointer_type = variable.PointerType(type_manager_);
             const uint32_t load_id = module_.TakeNextId();
             block.CreateInstruction(spv::OpLoad, {pointer_type->Id(), load_id, variable.Id()}, &inst_it);
@@ -177,7 +177,7 @@ uint32_t Pass::GetStageInfo(Function& function, const BasicBlock& target_block_i
             case spv::ExecutionModelTaskEXT:
             case spv::ExecutionModelMeshEXT: {
                 // This can be both a uvec3 or ivec3 so need to cast if ivec3
-                const Variable& variable = GetBuiltinVariable(spv::BuiltInGlobalInvocationId);
+                const Variable& variable = GetBuiltInVariable(spv::BuiltInGlobalInvocationId);
                 const Type* pointer_type = variable.PointerType(type_manager_);
                 const uint32_t load_id = module_.TakeNextId();
                 block.CreateInstruction(spv::OpLoad, {pointer_type->Id(), load_id, variable.Id()}, &inst_it);
@@ -681,6 +681,19 @@ uint32_t Pass::FindOffsetInStruct(uint32_t struct_id, const CooperativeMatrixAcc
 
                 current_type_id = current_type->inst_.Operand(constant_value);  // Get element type for next step
             } break;
+            case SpvType::kPointer: {
+                // So what this means is we have a pointer of structs, found in Slang doing something like
+                //
+                //     struct PerFrame {};
+                //     PerFrame* bufPerFrame;
+                //
+                // And the first PtrAccessChain is going to try and index into.
+                // There should be ArrayStride to know how large the Struct is
+                const uint32_t array_stride = GetDecoration(current_type_id, spv::DecorationArrayStride)->Word(3);
+                current_offset = constant_value * array_stride;
+
+                current_type_id = current_type->inst_.Word(3);  // Get pointer type
+            } break;
             default: {
                 module_.InternalError(Name(), "FindOffsetInStruct has unexpected non-composite type");
             } break;
@@ -932,6 +945,12 @@ InjectConditionalData Pass::InjectFunctionPre(Function& function, const BasicBlo
         invalid_block.CreateInstruction(spv::OpRayQueryInitializeKHR,
                                         {target_inst.Operand(0), target_inst.Operand(1), uint32_0_id, uint32_0_id, vec3_0_id,
                                          float32_0_id, vec3_0_id, float32_0_id});
+    } else if (target_inst.Opcode() == spv::OpSetMeshOutputsEXT) {
+        // TODO - Setup a callback system so MeshShading pass can set this as we should use the max values from the ExecutionMode
+        // instead, but don't want to be storing eveything in the Pass class as a global
+        const uint32_t three_id = type_manager_.CreateConstantUInt32(3).Id();
+        const uint32_t one_id = type_manager_.GetConstantOneUint32().Id();
+        invalid_block.CreateInstruction(spv::OpSetMeshOutputsEXT, {three_id, one_id});
     }
 
     invalid_block.CreateInstruction(spv::OpBranch, {merge_block_label});
