@@ -1,7 +1,7 @@
-/* Copyright (c) 2015-2025 The Khronos Group Inc.
- * Copyright (c) 2015-2025 Valve Corporation
- * Copyright (c) 2015-2025 LunarG, Inc.
- * Copyright (C) 2015-2025 Google Inc.
+/* Copyright (c) 2015-2026 The Khronos Group Inc.
+ * Copyright (c) 2015-2026 Valve Corporation
+ * Copyright (c) 2015-2026 LunarG, Inc.
+ * Copyright (C) 2015-2026 Google Inc.
  * Copyright (c) 2025 Arm Limited.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -1286,7 +1286,7 @@ void vvl::MutableDescriptor::WriteUpdate(DescriptorSet &set_state, const vvl::De
             break;
         case DescriptorClass::ImageSampler: {
             if (update.pImageInfo) {
-                const auto &image_info = update.pImageInfo[index];
+                const VkDescriptorImageInfo &image_info = update.pImageInfo[index];
                 if (!immutable_) {
                     ReplaceStatePtr(set_state, sampler_state_, dev_data.GetConstCastShared<vvl::Sampler>(image_info.sampler),
                                     is_bindless);
@@ -1299,7 +1299,8 @@ void vvl::MutableDescriptor::WriteUpdate(DescriptorSet &set_state, const vvl::De
         }
         case DescriptorClass::Image: {
             if (update.pImageInfo) {
-                const auto &image_info = update.pImageInfo[index];
+                // The VkSampler is ignored and may be garbage
+                const VkDescriptorImageInfo &image_info = update.pImageInfo[index];
                 image_layout_ = image_info.imageLayout;
                 ReplaceStatePtr(set_state, image_view_state_, dev_data.GetConstCastShared<vvl::ImageView>(image_info.imageView),
                                 is_bindless);
@@ -1308,7 +1309,7 @@ void vvl::MutableDescriptor::WriteUpdate(DescriptorSet &set_state, const vvl::De
         }
         case DescriptorClass::GeneralBuffer: {
             if (update.pBufferInfo) {
-                const auto &buffer_info = update.pBufferInfo[index];
+                const VkDescriptorBufferInfo &buffer_info = update.pBufferInfo[index];
                 offset_ = buffer_info.offset;
                 range_ = buffer_info.range;
                 // can be null if using nullDescriptors
@@ -1325,8 +1326,7 @@ void vvl::MutableDescriptor::WriteUpdate(DescriptorSet &set_state, const vvl::De
             assert(tensor_info);
             assert(index < tensor_info->tensorViewCount);
             const auto tensor_view_state = dev_data.GetConstCastShared<vvl::TensorView>(tensor_info->pTensorViews[index]);
-            const auto &tensor_state = tensor_view_state->tensor_state;
-            ReplaceStatePtr(set_state, tensor_state_, tensor_state, is_bindless);
+            ReplaceStatePtr(set_state, tensor_view_state_, tensor_view_state, is_bindless);
             break;
         }
         case DescriptorClass::TexelBuffer: {
@@ -1449,7 +1449,7 @@ void vvl::MutableDescriptor::CopyUpdate(DescriptorSet &set_state, const vvl::Dev
                     ReplaceStatePtr(set_state, buffer_view_state_, mutable_src.GetSharedBufferViewState(), is_bindless);
                 } break;
                 case DescriptorClass::Tensor: {
-                    ReplaceStatePtr(set_state, tensor_state_, mutable_src.GetSharedTensor(), is_bindless);
+                    ReplaceStatePtr(set_state, tensor_view_state_, mutable_src.GetSharedTensorView(), is_bindless);
                 } break;
                 case DescriptorClass::AccelerationStructure: {
                     if (mutable_src.IsKHR()) {
@@ -1475,7 +1475,7 @@ void vvl::MutableDescriptor::CopyUpdate(DescriptorSet &set_state, const vvl::Dev
             const auto tensor_desc = static_cast<const MutableDescriptor *>(&src);
             tensor_view_count_ = tensor_desc->GetTensorViewCount();
             tensor_views_ = tensor_desc->GetTensorViews();
-            ReplaceStatePtr(set_state, tensor_state_, std::shared_ptr<vvl::Tensor>(), is_bindless);
+            ReplaceStatePtr(set_state, tensor_view_state_, std::shared_ptr<vvl::TensorView>(), is_bindless);
         } break;
         case vvl::DescriptorClass::InlineUniform:
         case vvl::DescriptorClass::Invalid:
@@ -1500,6 +1500,8 @@ VkDeviceSize vvl::MutableDescriptor::GetEffectiveRange() const {
     }
 }
 
+std::shared_ptr<vvl::Tensor> vvl::MutableDescriptor::GetSharedTensor() const { return tensor_view_state_->tensor_state; }
+
 void vvl::MutableDescriptor::UpdateImageLayoutDrawState(vvl::CommandBuffer &cb_state) {
     const vvl::DescriptorClass active_class = ActiveClass();
     if (active_class == DescriptorClass::Image || active_class == DescriptorClass::ImageSampler) {
@@ -1550,8 +1552,8 @@ bool vvl::MutableDescriptor::AddParent(StateObject *state_object) {
             }
             break;
         case DescriptorClass::Tensor:
-            if (tensor_state_) {
-                result |= tensor_state_->AddParent(state_object);
+            if (tensor_view_state_) {
+                result |= tensor_view_state_->AddParent(state_object);
             }
             break;
         case DescriptorClass::InlineUniform:
@@ -1580,8 +1582,8 @@ void vvl::MutableDescriptor::RemoveParent(StateObject *state_object) {
     if (acc_state_nv_) {
         acc_state_nv_->RemoveParent(state_object);
     }
-    if (tensor_state_) {
-        tensor_state_->RemoveParent(state_object);
+    if (tensor_view_state_) {
+        tensor_view_state_->RemoveParent(state_object);
     }
 }
 
@@ -1609,7 +1611,8 @@ bool vvl::MutableDescriptor::Invalid() const {
                 return !acc_state_nv_ || acc_state_nv_->Invalid();
             }
         case DescriptorClass::Tensor:
-            return !tensor_state_ || tensor_state_->Invalid();
+            return !tensor_view_state_ || tensor_view_state_->Invalid() || !tensor_view_state_->tensor_state ||
+                   tensor_view_state_->tensor_state->Invalid();
 
         case DescriptorClass::InlineUniform:
         case DescriptorClass::Mutable:
@@ -1620,7 +1623,7 @@ bool vvl::MutableDescriptor::Invalid() const {
 }
 
 std::string vvl::DslErrorSource::PrintMessage(const Logger &error_logger) const {
-    std::stringstream msg;
+    std::ostringstream msg;
     msg << "The VkDescriptorSetLayout was used to ";
     if (pipeline_layout_handle_ == VK_NULL_HANDLE) {
         msg << "allocate " << error_logger.FormatHandle(ds_handle_);
@@ -1645,11 +1648,13 @@ void vvl::TensorDescriptor::CopyUpdate(DescriptorSet &set_state, const DeviceSta
         const auto tensor_desc = static_cast<const MutableDescriptor *>(&src);
         tensor_view_count_ = tensor_desc->GetTensorViewCount();
         tensor_views_ = tensor_desc->GetTensorViews();
-        ReplaceStatePtr(set_state, tensor_state_, std::shared_ptr<vvl::Tensor>(), is_bindless);
+        ReplaceStatePtr(set_state, tensor_view_state_, std::shared_ptr<vvl::TensorView>(), is_bindless);
         return;
     }
     const auto tensor_desc = static_cast<const TensorDescriptor *>(&src);
     tensor_view_count_ = tensor_desc->tensor_view_count_;
     tensor_views_ = tensor_desc->tensor_views_;
-    ReplaceStatePtr(set_state, tensor_state_, std::shared_ptr<vvl::Tensor>(), is_bindless);
+    ReplaceStatePtr(set_state, tensor_view_state_, std::shared_ptr<vvl::TensorView>(), is_bindless);
 }
+
+const vvl::Tensor *vvl::TensorDescriptor::GetTensorState() const { return tensor_view_state_->tensor_state.get(); }
