@@ -19,7 +19,7 @@
 #pragma once
 
 #include "state_tracker/pipeline_layout_state.h"
-#include "utils/vk_api_utils.h"
+#include "state_tracker/descriptor_mode.h"
 #include "utils/shader_utils.h"
 #include "generated/dynamic_state_helper.h"
 #include "generated/error_location_helper.h"
@@ -132,17 +132,21 @@ struct LastBound {
     VkPrimitiveTopology ClipSpaceTopology() const;
     VkPrimitiveTopology GetRasterizationInputTopology() const;
 
-    VkShaderEXT GetShader(ShaderObjectStage stage) const;
-    vvl::ShaderObject *GetShaderState(ShaderObjectStage stage) const;
-    const vvl::ShaderObject *GetShaderStateIfValid(ShaderObjectStage stage) const;
+    bool IsSampleShadingEnabled() const;
+    float GetMinSampleShading() const;
+    std::string DescribeSampleShading() const;
+
+    VkShaderEXT GetShaderObject(ShaderObjectStage stage) const;
+    vvl::ShaderObject *GetShaderObjectState(ShaderObjectStage stage) const;
+    const vvl::ShaderObject *GetShaderObjectStateIfValid(ShaderObjectStage stage) const;
     // Return compute shader for compute pipeline, vertex or mesh shader for graphics
     const vvl::ShaderObject *GetFirstShader() const;
     bool HasShaderObjects() const;
-    bool IsValidShaderBound(ShaderObjectStage stage) const;
-    bool IsValidShaderOrNullBound(ShaderObjectStage stage) const;
-    std::vector<vvl::ShaderObject *> GetAllBoundGraphicsShaders();
-    bool IsAnyGraphicsShaderBound() const;
-    bool IsFragmentBound() const;
+    bool IsValidShaderObjectBound(ShaderObjectStage stage) const;
+    bool IsValidShaderObjectOrNullBound(ShaderObjectStage stage) const;
+    std::vector<vvl::ShaderObject *> GetAllBoundGraphicsShaderObjects();
+    bool IsStageBound(VkShaderStageFlagBits stage) const;
+    bool IsAnyGraphicsStageBound() const;
     VkShaderStageFlags GetAllActiveBoundStages() const;
     bool IsBoundSetCompatible(uint32_t set, const vvl::PipelineLayout &pipeline_layout) const;
     bool IsBoundSetCompatible(uint32_t set, const vvl::ShaderObject &shader_object_state) const;
@@ -151,74 +155,13 @@ struct LastBound {
 
     const spirv::EntryPoint *GetVertexEntryPoint() const;
     const spirv::EntryPoint *GetFragmentEntryPoint() const;
+
+    // Since GPU-AV uses this to access an array, force a getter to ensure people use this correctly.
+    vvl::DescriptorMode GetActionDescriptorMode() const;
+    vvl::DescriptorMode GetDescriptorMode() const { return descriptor_mode; };
+    void SetDescriptorMode(vvl::DescriptorMode mode) { descriptor_mode = mode; };
+
+  private:
+    // While Descriptor Buffer are bound to all bindpoint, Classic is only tied to a single bind point.
+    vvl::DescriptorMode descriptor_mode = vvl::DescriptorModeUnknown;
 };
-
-namespace vvl {
-// Need to be values that can be used to access an array for each bind point
-enum BindPoint {
-    BindPointGraphics = 0, // VK_PIPELINE_BIND_POINT_GRAPHICS
-    BindPointCompute = 1, // VK_PIPELINE_BIND_POINT_COMPUTE
-    BindPointRayTracing = 2, // VK_PIPELINE_BIND_POINT_RAY_TRACING_KHR
-    BindPointDataGraph = 3, // VK_PIPELINE_BIND_POINT_DATA_GRAPH_ARM
-    BindPointCount = 4,
-};
-}  // namespace vvl
-
-static vvl::BindPoint inline ConvertToVvlBindPoint(VkPipelineBindPoint bind_point) {
-    switch (bind_point) {
-        case VK_PIPELINE_BIND_POINT_GRAPHICS:
-            return vvl::BindPointGraphics;
-        case VK_PIPELINE_BIND_POINT_COMPUTE:
-            return vvl::BindPointCompute;
-        case VK_PIPELINE_BIND_POINT_RAY_TRACING_KHR:
-            return vvl::BindPointRayTracing;
-        case VK_PIPELINE_BIND_POINT_DATA_GRAPH_ARM:
-            return vvl::BindPointDataGraph;
-        default:
-            break;
-    }
-    assert(false);
-    return vvl::BindPointGraphics;
-}
-
-// Used for things like Device Generated Commands which supply multiple stages (but all need to be in a single bind point)
-static VkPipelineBindPoint inline ConvertStageToBindPoint(VkShaderStageFlags stage) {
-    // Assumes the call has checked stages have not been mixed
-    if (stage & kShaderStageAllGraphics) {
-        return VK_PIPELINE_BIND_POINT_GRAPHICS;
-    } else if (stage & VK_SHADER_STAGE_COMPUTE_BIT) {
-        return VK_PIPELINE_BIND_POINT_COMPUTE;
-    } else if (stage & kShaderStageAllRayTracing) {
-        return VK_PIPELINE_BIND_POINT_RAY_TRACING_KHR;
-    } else {
-        assert(false);
-        return VK_PIPELINE_BIND_POINT_GRAPHICS;
-    }
-}
-
-// Used to get last bound for shader object which only has a single stage
-static vvl::BindPoint inline ConvertStageToVvlBindPoint(VkShaderStageFlagBits stage) {
-    switch (stage) {
-        case VK_SHADER_STAGE_VERTEX_BIT:
-        case VK_SHADER_STAGE_TESSELLATION_CONTROL_BIT:
-        case VK_SHADER_STAGE_TESSELLATION_EVALUATION_BIT:
-        case VK_SHADER_STAGE_GEOMETRY_BIT:
-        case VK_SHADER_STAGE_FRAGMENT_BIT:
-        case VK_SHADER_STAGE_TASK_BIT_EXT:
-        case VK_SHADER_STAGE_MESH_BIT_EXT:
-            return vvl::BindPointGraphics;
-        case VK_SHADER_STAGE_COMPUTE_BIT:
-            return vvl::BindPointCompute;
-        case VK_SHADER_STAGE_RAYGEN_BIT_KHR:
-        case VK_SHADER_STAGE_ANY_HIT_BIT_KHR:
-        case VK_SHADER_STAGE_CLOSEST_HIT_BIT_KHR:
-        case VK_SHADER_STAGE_MISS_BIT_KHR:
-        case VK_SHADER_STAGE_INTERSECTION_BIT_KHR:
-        case VK_SHADER_STAGE_CALLABLE_BIT_KHR:
-            return vvl::BindPointRayTracing;
-        default:
-            break;
-    }
-    assert(false);
-    return vvl::BindPointGraphics;
-}
