@@ -19,7 +19,6 @@
 
 #include "state_tracker/render_pass_state.h"
 #include "utils/convert_utils.h"
-#include "utils/math_utils.h"
 #include "state_tracker/image_state.h"
 #include "containers/span.h"
 
@@ -286,9 +285,9 @@ RenderPass::RenderPass(VkRenderPass handle, VkRenderPassCreateInfo2 const *pCrea
       create_info(pCreateInfo),
       use_dynamic_rendering(false),
       use_dynamic_rendering_inherited(false),
-      has_multiview_enabled(IsRenderPassMultiViewEnabled(*create_info.ptr())),
       rasterization_enabled(true),
-      dynamic_rendering_color_attachment_count(0) {
+      dynamic_rendering_color_attachment_count(0),
+      has_multiview_enabled(IsRenderPassMultiViewEnabled(*create_info.ptr())) {
     InitRenderPassState(*this);
 }
 
@@ -303,9 +302,9 @@ RenderPass::RenderPass(VkRenderPass handle, VkRenderPassCreateInfo const *pCreat
       create_info(ConvertCreateInfo(*pCreateInfo)),
       use_dynamic_rendering(false),
       use_dynamic_rendering_inherited(false),
-      has_multiview_enabled(IsRenderPassMultiViewEnabled(*create_info.ptr())),
       rasterization_enabled(true),
-      dynamic_rendering_color_attachment_count(0) {
+      dynamic_rendering_color_attachment_count(0),
+      has_multiview_enabled(IsRenderPassMultiViewEnabled(*create_info.ptr())) {
     InitRenderPassState(*this);
 }
 
@@ -317,12 +316,12 @@ RenderPass::RenderPass(VkPipelineRenderingCreateInfo const *pPipelineRenderingCr
     : StateObject(static_cast<VkRenderPass>(VK_NULL_HANDLE), kVulkanObjectTypeRenderPass),
       use_dynamic_rendering(true),
       use_dynamic_rendering_inherited(false),
-      has_multiview_enabled(false),
       rasterization_enabled(rasterization_enabled),
       dynamic_pipeline_rendering_create_info((pPipelineRenderingCreateInfo && rasterization_enabled)
                                                  ? pPipelineRenderingCreateInfo
                                                  : &VkPipelineRenderingCreateInfo_default),
-      dynamic_rendering_color_attachment_count(dynamic_pipeline_rendering_create_info.colorAttachmentCount) {}
+      dynamic_rendering_color_attachment_count(dynamic_pipeline_rendering_create_info.colorAttachmentCount),
+      has_multiview_enabled(dynamic_pipeline_rendering_create_info.viewMask != 0) {}
 
 bool RenderPass::UsesColorAttachment(uint32_t subpass_num) const {
     bool result = false;
@@ -388,20 +387,6 @@ VkRenderingFlags RenderPass::GetRenderingFlags() const {
     return 0;
 }
 
-uint32_t RenderPass::GetViewMaskBits(uint32_t subpass) const {
-    if (use_dynamic_rendering_inherited) {
-        return GetBitSetCount(inheritance_rendering_info.viewMask);
-    } else if (use_dynamic_rendering) {
-        return GetBitSetCount(dynamic_rendering_begin_rendering_info.viewMask);
-    } else {
-        const auto *subpass_desc = &create_info.pSubpasses[subpass];
-        if (subpass_desc) {
-            return GetBitSetCount(subpass_desc->viewMask);
-        }
-    }
-    return 0;
-}
-
 const VkMultisampledRenderToSingleSampledInfoEXT *RenderPass::GetMSRTSSInfo(uint32_t subpass) const {
     if (UsesDynamicRendering()) {
         return vku::FindStructInPNextChain<VkMultisampledRenderToSingleSampledInfoEXT>(
@@ -415,21 +400,21 @@ RenderPass::RenderPass(VkRenderingInfo const *pRenderingInfo, bool rasterization
     : StateObject(static_cast<VkRenderPass>(VK_NULL_HANDLE), kVulkanObjectTypeRenderPass),
       use_dynamic_rendering(true),
       use_dynamic_rendering_inherited(false),
-      has_multiview_enabled(
-          IsDynamicRenderingMultiviewEnabled((pRenderingInfo && rasterization_enabled) ? pRenderingInfo : nullptr)),
       rasterization_enabled(rasterization_enabled),
       dynamic_rendering_begin_rendering_info((pRenderingInfo && rasterization_enabled) ? pRenderingInfo : nullptr),
-      dynamic_rendering_color_attachment_count(dynamic_rendering_begin_rendering_info.colorAttachmentCount) {}
+      dynamic_rendering_color_attachment_count(dynamic_rendering_begin_rendering_info.colorAttachmentCount),
+      has_multiview_enabled(
+          IsDynamicRenderingMultiviewEnabled((pRenderingInfo && rasterization_enabled) ? pRenderingInfo : nullptr)) {}
 
 // vkBeginCommandBuffer (dynamic rendering in secondary command buffer)
 RenderPass::RenderPass(VkCommandBufferInheritanceRenderingInfo const *pInheritanceRenderingInfo)
     : StateObject(static_cast<VkRenderPass>(VK_NULL_HANDLE), kVulkanObjectTypeRenderPass),
       use_dynamic_rendering(false),
       use_dynamic_rendering_inherited(true),
-      has_multiview_enabled(false),
       rasterization_enabled(true),
       inheritance_rendering_info(pInheritanceRenderingInfo),
-      dynamic_rendering_color_attachment_count(inheritance_rendering_info.colorAttachmentCount) {}
+      dynamic_rendering_color_attachment_count(inheritance_rendering_info.colorAttachmentCount),
+      has_multiview_enabled(false) {}
 
 Framebuffer::Framebuffer(VkFramebuffer handle, const VkFramebufferCreateInfo *pCreateInfo, std::shared_ptr<RenderPass> &&rpstate,
                          std::vector<std::shared_ptr<vvl::ImageView>> &&attachments)
