@@ -554,7 +554,7 @@ class RateControlStateMismatchRecorder {
 
   private:
     bool has_mismatch_{};
-    std::stringstream stream_{};
+    std::ostringstream stream_{};
     mutable std::string string_{};
 };
 
@@ -1062,7 +1062,7 @@ void VideoSessionParameters::AddEncodeH265(VkVideoEncodeH265SessionParametersAdd
 }
 
 std::string string_VideoProfileDesc(const vvl::VideoProfileDesc &profile) {
-    std::stringstream ss;
+    std::ostringstream ss;
     const vvl::VideoProfileDesc::Profile &internal_profile = profile.GetProfile();
 
     switch (internal_profile.base.videoCodecOperation) {
@@ -1130,7 +1130,8 @@ std::string string_VideoProfileDesc(const vvl::VideoProfileDesc &profile) {
     };
 
     ss << string_video_component_bit_depth(internal_profile.base.lumaBitDepth);
-    if (internal_profile.base.lumaBitDepth != internal_profile.base.chromaBitDepth) {
+    if (internal_profile.base.chromaSubsampling != VK_VIDEO_CHROMA_SUBSAMPLING_MONOCHROME_BIT_KHR &&
+        internal_profile.base.lumaBitDepth != internal_profile.base.chromaBitDepth) {
         ss << ":" << string_video_component_bit_depth(internal_profile.base.chromaBitDepth);
     }
     ss << "-bit) ";
@@ -1247,9 +1248,9 @@ std::string string_VideoProfileDesc(const vvl::VideoProfileDesc &profile) {
 }
 
 std::string string_SupportedVideoProfiles(const SupportedVideoProfiles &profiles) {
-    std::stringstream ss;
+    std::ostringstream ss;
 
-    if (profiles.size() != 0) {
+    if (!profiles.empty()) {
         for (const auto &profile : profiles) {
             ss << "\t" << string_VideoProfileDesc(*profile) << "\n";
         }
