@@ -1,7 +1,7 @@
-/* Copyright (c) 2015-2025 The Khronos Group Inc.
- * Copyright (c) 2015-2025 Valve Corporation
- * Copyright (c) 2015-2025 LunarG, Inc.
- * Copyright (C) 2015-2024 Google Inc.
+/* Copyright (c) 2015-2026 The Khronos Group Inc.
+ * Copyright (c) 2015-2026 Valve Corporation
+ * Copyright (c) 2015-2026 LunarG, Inc.
+ * Copyright (C) 2015-2026 Google Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -25,6 +25,7 @@
 #include "containers/container_utils.h"
 #include "utils/math_utils.h"
 #include "utils/image_utils.h"
+#include <cmath>
 
 namespace stateless {
 
@@ -38,17 +39,13 @@ bool Device::manual_PreCallValidateCreateImage(VkDevice device, const VkImageCre
         return skip;
     }
     const Location create_info_loc = error_obj.location.dot(Field::pCreateInfo);
-    // Validation for parameters excluded from the generated validation code due to a 'noautovalidity' tag in vk.xml
     if (pCreateInfo->sharingMode == VK_SHARING_MODE_CONCURRENT) {
-        // If sharingMode is VK_SHARING_MODE_CONCURRENT, queueFamilyIndexCount must be greater than 1
         auto const queue_family_index_count = pCreateInfo->queueFamilyIndexCount;
         if (queue_family_index_count <= 1) {
             skip |= LogError("VUID-VkImageCreateInfo-sharingMode-00942", device, create_info_loc.dot(Field::queueFamilyIndexCount),
                              "is %" PRIu32 ".", queue_family_index_count);
         }
 
-        // If sharingMode is VK_SHARING_MODE_CONCURRENT, pQueueFamilyIndices must be a pointer to an array of
-        // queueFamilyIndexCount uint32_t values
         if (pCreateInfo->pQueueFamilyIndices == nullptr) {
             skip |= LogError("VUID-VkImageCreateInfo-sharingMode-00941", device, create_info_loc.dot(Field::pQueueFamilyIndices),
                              "is NULL.");
@@ -113,7 +110,6 @@ bool Device::manual_PreCallValidateCreateImage(VkDevice device, const VkImageCre
         }
     }
 
-    // 3D image may have only 1 layer
     if ((pCreateInfo->imageType == VK_IMAGE_TYPE_3D) && (pCreateInfo->arrayLayers != 1)) {
         skip |= LogError("VUID-VkImageCreateInfo-imageType-00961", device, create_info_loc.dot(Field::imageType),
                          "is VK_IMAGE_TYPE_3D but arrayLayers (%" PRIu32 ") must be 1.", pCreateInfo->arrayLayers);
@@ -122,13 +118,11 @@ bool Device::manual_PreCallValidateCreateImage(VkDevice device, const VkImageCre
     if (0 != (pCreateInfo->usage & VK_IMAGE_USAGE_TRANSIENT_ATTACHMENT_BIT)) {
         VkImageUsageFlags legal_flags = (VK_IMAGE_USAGE_COLOR_ATTACHMENT_BIT | VK_IMAGE_USAGE_DEPTH_STENCIL_ATTACHMENT_BIT |
                                          VK_IMAGE_USAGE_INPUT_ATTACHMENT_BIT);
-        // At least one of the legal attachment bits must be set
         if (0 == (pCreateInfo->usage & legal_flags)) {
             skip |= LogError("VUID-VkImageCreateInfo-usage-00966", device, create_info_loc.dot(Field::usage),
                              "(%s) includes VK_IMAGE_USAGE_TRANSIENT_ATTACHMENT_BIT but is missing one of %s.",
                              string_VkImageUsageFlags(pCreateInfo->usage).c_str(), string_VkImageUsageFlags(legal_flags).c_str());
         }
-        // No flags other than the legal attachment bits may be set
         legal_flags |= VK_IMAGE_USAGE_TRANSIENT_ATTACHMENT_BIT;
         if (0 != (pCreateInfo->usage & ~legal_flags)) {
             skip |= LogError("VUID-VkImageCreateInfo-usage-00963", device, create_info_loc,
@@ -199,6 +193,11 @@ bool Device::manual_PreCallValidateCreateImage(VkDevice device, const VkImageCre
                          "includes VK_IMAGE_USAGE_HOST_TRANSFER_BIT, but hostImageCopy feature was not enabled.");
     }
 
+    if (!enabled_features.tileMemoryHeap && (pCreateInfo->usage & VK_IMAGE_USAGE_TILE_MEMORY_BIT_QCOM) != 0) {
+        skip |= LogError("VUID-VkImageCreateInfo-tileMemoryHeap-10766", device, create_info_loc.dot(Field::usage),
+                         "includes VK_IMAGE_USAGE_TILE_MEMORY_BIT_QCOM, but tileMemoryHeap feature was not enabled.");
+    }
+
     static const uint64_t drm_format_mod_linear = 0;
     bool image_create_maybe_linear = false;
     if (pCreateInfo->tiling == VK_IMAGE_TILING_LINEAR) {
@@ -319,10 +318,11 @@ bool Device::manual_PreCallValidateCreateImage(VkDevice device, const VkImageCre
         }
     }
 
-    if ((image_flags & VK_IMAGE_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXT) &&
+    if ((image_flags & VK_IMAGE_CREATE_DESCRIPTOR_HEAP_CAPTURE_REPLAY_BIT_EXT) && !enabled_features.descriptorHeapCaptureReplay &&
         !enabled_features.descriptorBufferCaptureReplay) {
         skip |= LogError("VUID-VkImageCreateInfo-flags-08104", device, create_info_loc.dot(Field::flags),
-                         "contains VK_IMAGE_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXT but the descriptorBufferCaptureReplay "
+                         "contains VK_IMAGE_CREATE_DESCRIPTOR_HEAP_CAPTURE_REPLAY_BIT_EXT but neither descriptorHeapCaptureReplay "
+                         "nor descriptorBufferCaptureReplay "
                          "feature is not enabled.");
     }
 
@@ -350,17 +350,24 @@ bool Device::manual_PreCallValidateCreateImage(VkDevice device, const VkImageCre
     }
 
     // If Chroma subsampled format ( _420_ or _422_ )
-    if (vkuFormatIsXChromaSubsampled(image_format) && (SafeModulo(pCreateInfo->extent.width, 2) != 0)) {
+    if (vkuFormatIsXChromaSubsampled(image_format) && !IsIntegerMultipleOf(pCreateInfo->extent.width, 2)) {
         skip |=
             LogError("VUID-VkImageCreateInfo-format-04712", device, create_info_loc.dot(Field::format),
                      "(%s) is X Chroma Subsampled (has _422 or _420 suffix) so the width (%" PRIu32 ") must be a multiple of 2.",
                      string_VkFormat(image_format), pCreateInfo->extent.width);
     }
-    if (vkuFormatIsYChromaSubsampled(image_format) && (SafeModulo(pCreateInfo->extent.height, 2) != 0)) {
+    if (vkuFormatIsYChromaSubsampled(image_format) && !IsIntegerMultipleOf(pCreateInfo->extent.height, 2)) {
         skip |= LogError("VUID-VkImageCreateInfo-format-04713", device, create_info_loc.dot(Field::format),
                          "(%s) is Y Chroma Subsampled (has _420 suffix) so the height (%" PRIu32 ") must be a multiple of 2.",
                          string_VkFormat(image_format), pCreateInfo->extent.height);
     }
+    if (api_version < VK_API_VERSION_1_3 && !enabled_features.ycbcr2plane444Formats) {
+        if (IsValueIn(image_format, {VK_FORMAT_G8_B8R8_2PLANE_444_UNORM, VK_FORMAT_G10X6_B10X6R10X6_2PLANE_444_UNORM_3PACK16,
+                                     VK_FORMAT_G12X4_B12X4R12X4_2PLANE_444_UNORM_3PACK16, VK_FORMAT_G16_B16R16_2PLANE_444_UNORM})) {
+            skip |= LogError("VUID-VkImageCreateInfo-None-12279", device, create_info_loc.dot(Field::format), "is %s.",
+                             string_VkFormat(image_format));
+        }
+    }
 
     return skip;
 }
@@ -400,8 +407,6 @@ bool Device::ValidateCreateImageSparse(const VkImageCreateInfo &create_info, con
                          "includes VK_IMAGE_CREATE_SPARSE_ALIASED_BIT but the sparseResidencyAliased feature was not enabled.");
     }
 
-    // If flags contains VK_IMAGE_CREATE_SPARSE_RESIDENCY_BIT or VK_IMAGE_CREATE_SPARSE_ALIASED_BIT, it must also contain
-    // VK_IMAGE_CREATE_SPARSE_BINDING_BIT
     if (((image_flags & (VK_IMAGE_CREATE_SPARSE_RESIDENCY_BIT | VK_IMAGE_CREATE_SPARSE_ALIASED_BIT)) != 0) &&
         ((image_flags & VK_IMAGE_CREATE_SPARSE_BINDING_BIT) != VK_IMAGE_CREATE_SPARSE_BINDING_BIT)) {
         skip |= LogError("VUID-VkImageCreateInfo-flags-00987", device, create_info_loc.dot(Field::flags), "is %s.",
@@ -410,33 +415,28 @@ bool Device::ValidateCreateImageSparse(const VkImageCreateInfo &create_info, con
 
     // Check for combinations of attributes that are incompatible with having VK_IMAGE_CREATE_SPARSE_RESIDENCY_BIT set
     if ((image_flags & VK_IMAGE_CREATE_SPARSE_RESIDENCY_BIT) != 0) {
-        // Linear tiling is unsupported
         if (VK_IMAGE_TILING_LINEAR == create_info.tiling) {
             skip |= LogError("VUID-VkImageCreateInfo-tiling-04121", device, create_info_loc.dot(Field::flags),
                              "includes VK_IMAGE_CREATE_SPARSE_RESIDENCY_BIT but tiling is VK_IMAGE_TILING_LINEAR.");
         }
 
-        // Sparse 1D image isn't valid
         if (VK_IMAGE_TYPE_1D == create_info.imageType) {
             skip |= LogError("VUID-VkImageCreateInfo-imageType-00970", device, create_info_loc.dot(Field::flags),
                              "includes VK_IMAGE_CREATE_SPARSE_BINDING_BIT but imageType is VK_IMAGE_TYPE_1D.");
         }
 
-        // Sparse 2D image when device doesn't support it
         if ((!enabled_features.sparseResidencyImage2D) && (VK_IMAGE_TYPE_2D == create_info.imageType)) {
             skip |= LogError("VUID-VkImageCreateInfo-imageType-00971", device, create_info_loc.dot(Field::flags),
                              "includes VK_IMAGE_CREATE_SPARSE_BINDING_BIT and imageType is VK_IMAGE_TYPE_2D, but "
                              "sparseResidencyImage2D feature was not enabled.");
         }
 
-        // Sparse 3D image when device doesn't support it
         if ((!enabled_features.sparseResidencyImage3D) && (VK_IMAGE_TYPE_3D == create_info.imageType)) {
             skip |= LogError("VUID-VkImageCreateInfo-imageType-00972", device, create_info_loc.dot(Field::flags),
                              "includes VK_IMAGE_CREATE_SPARSE_BINDING_BIT and imageType is VK_IMAGE_TYPE_3D, but "
                              "sparseResidencyImage3D feature was not enabled.");
         }
 
-        // Multi-sample 2D image when device doesn't support it
         if (VK_IMAGE_TYPE_2D == create_info.imageType) {
             if ((!enabled_features.sparseResidency2Samples) && (VK_SAMPLE_COUNT_2_BIT == create_info.samples)) {
                 skip |= LogError("VUID-VkImageCreateInfo-imageType-00973", device, create_info_loc.dot(Field::flags),
@@ -527,7 +527,6 @@ bool Device::ValidateCreateImageStencilUsage(const VkImageCreateInfo &create_inf
 
     if ((image_stencil_struct->stencilUsage & VK_IMAGE_USAGE_TRANSIENT_ATTACHMENT_BIT) != 0) {
         VkImageUsageFlags legal_flags = (VK_IMAGE_USAGE_DEPTH_STENCIL_ATTACHMENT_BIT | VK_IMAGE_USAGE_INPUT_ATTACHMENT_BIT);
-        // No flags other than the legal attachment bits may be set
         legal_flags |= VK_IMAGE_USAGE_TRANSIENT_ATTACHMENT_BIT;
         if ((image_stencil_struct->stencilUsage & ~legal_flags) != 0) {
             skip |= LogError("VUID-VkImageStencilUsageCreateInfo-stencilUsage-02539", device,
@@ -538,22 +537,22 @@ bool Device::ValidateCreateImageStencilUsage(const VkImageCreateInfo &create_inf
 
     if (vkuFormatIsDepthOrStencil(create_info.format)) {
         if ((image_stencil_struct->stencilUsage & VK_IMAGE_USAGE_INPUT_ATTACHMENT_BIT) != 0) {
-            if (create_info.extent.width > device_limits.maxFramebufferWidth) {
+            if (create_info.extent.width > phys_dev_props.limits.maxFramebufferWidth) {
                 skip |= LogError("VUID-VkImageCreateInfo-Format-02536", device,
                                  create_info_loc.pNext(Struct::VkImageStencilUsageCreateInfo, Field::stencilUsage),
                                  "includes VK_IMAGE_USAGE_INPUT_ATTACHMENT_BIT and image width (%" PRIu32
                                  ") exceeds device "
                                  "maxFramebufferWidth (%" PRIu32 ")",
-                                 create_info.extent.width, device_limits.maxFramebufferWidth);
+                                 create_info.extent.width, phys_dev_props.limits.maxFramebufferWidth);
             }
 
-            if (create_info.extent.height > device_limits.maxFramebufferHeight) {
+            if (create_info.extent.height > phys_dev_props.limits.maxFramebufferHeight) {
                 skip |= LogError("VUID-VkImageCreateInfo-format-02537", device,
                                  create_info_loc.pNext(Struct::VkImageStencilUsageCreateInfo, Field::stencilUsage),
                                  "includes VK_IMAGE_USAGE_INPUT_ATTACHMENT_BIT and image height (%" PRIu32
                                  ") exceeds device "
                                  "maxFramebufferHeight (%" PRIu32 ")",
-                                 create_info.extent.height, device_limits.maxFramebufferHeight);
+                                 create_info.extent.height, phys_dev_props.limits.maxFramebufferHeight);
             }
         }
 
@@ -735,7 +734,7 @@ bool Device::ValidateCreateImageFormatList(const VkImageCreateInfo &create_info,
                     found_compatible = true;
                 }
                 if (!found_compatible) {
-                    std::stringstream ss;
+                    std::ostringstream ss;
                     ss << "Plane 0 " << string_VkFormat(plane_0_format);
                     if (plane_count > 1) {
                         ss << "\nPlane 1 " << string_VkFormat(plane_1_format);
@@ -799,7 +798,7 @@ bool Device::ValidateCreateImageMetalObject(const VkImageCreateInfo &create_info
             skip |=
                 LogError("VUID-VkImageCreateInfo-pNext-06785", device, texture_info_loc,
                          "is %s, but only VK_IMAGE_ASPECT_PLANE_0_BIT is allowed for an image created with format %s, "
-                         "which is not multiplaner",
+                         "which is not multiplanar",
                          string_VkImageAspectFlags(import_metal_texture_info->plane).c_str(), string_VkFormat(create_info.format));
         }
         if ((format_plane_count == 2) && (import_metal_texture_info->plane == VK_IMAGE_ASPECT_PLANE_2_BIT)) {
@@ -820,21 +819,21 @@ bool Device::ValidateCreateImageDrmFormatModifiers(const VkImageCreateInfo &crea
     if (!IsExtEnabled(extensions.vk_ext_image_drm_format_modifier)) return skip;
 
     const auto drm_format_mod_list = vku::FindStructInPNextChain<VkImageDrmFormatModifierListCreateInfoEXT>(create_info.pNext);
-    const auto drm_format_mod_explict =
+    const auto drm_format_mod_explicit =
         vku::FindStructInPNextChain<VkImageDrmFormatModifierExplicitCreateInfoEXT>(create_info.pNext);
     if (create_info.tiling == VK_IMAGE_TILING_DRM_FORMAT_MODIFIER_EXT) {
-        if ((!drm_format_mod_list) && (!drm_format_mod_explict)) {
+        if ((!drm_format_mod_list) && (!drm_format_mod_explicit)) {
             skip |= LogError("VUID-VkImageCreateInfo-tiling-02261", device, create_info_loc.dot(Field::tiling),
                              "is VK_IMAGE_TILING_DRM_FORMAT_MODIFIER_EXT but pNext is missing "
                              "VkImageDrmFormatModifierListCreateInfoEXT or "
                              "VkImageDrmFormatModifierExplicitCreateInfoEXT.");
-        } else if ((drm_format_mod_list) && (drm_format_mod_explict)) {
+        } else if ((drm_format_mod_list) && (drm_format_mod_explicit)) {
             skip |= LogError("VUID-VkImageCreateInfo-tiling-02261", device, create_info_loc.dot(Field::tiling),
                              "is VK_IMAGE_TILING_DRM_FORMAT_MODIFIER_EXT but pNext has both "
                              "VkImageDrmFormatModifierListCreateInfoEXT and "
                              "VkImageDrmFormatModifierExplicitCreateInfoEXT.");
-        } else if (drm_format_mod_explict) {
-            image_create_drm_format_modifiers.push_back(drm_format_mod_explict->drmFormatModifier);
+        } else if (drm_format_mod_explicit) {
+            image_create_drm_format_modifiers.push_back(drm_format_mod_explicit->drmFormatModifier);
         } else if (drm_format_mod_list) {
             for (uint32_t i = 0; i < drm_format_mod_list->drmFormatModifierCount; i++) {
                 image_create_drm_format_modifiers.push_back(*drm_format_mod_list->pDrmFormatModifiers);
@@ -858,36 +857,36 @@ bool Device::ValidateCreateImageDrmFormatModifiers(const VkImageCreateInfo &crea
                          "is %s, but there is a "
                          "VkImageDrmFormatModifierListCreateInfoEXT in the pNext chain",
                          string_VkImageTiling(create_info.tiling));
-    } else if (drm_format_mod_explict) {
+    } else if (drm_format_mod_explicit) {
         skip |= LogError("VUID-VkImageCreateInfo-pNext-02262", device, create_info_loc.dot(Field::tiling),
                          "is %s, but there is a VkImageDrmFormatModifierExplicitCreateInfoEXT "
                          "in the pNext chain",
                          string_VkImageTiling(create_info.tiling));
     }
 
-    if (drm_format_mod_explict && drm_format_mod_explict->pPlaneLayouts) {
-        for (uint32_t i = 0; i < drm_format_mod_explict->drmFormatModifierPlaneCount; ++i) {
+    if (drm_format_mod_explicit && drm_format_mod_explicit->pPlaneLayouts) {
+        for (uint32_t i = 0; i < drm_format_mod_explicit->drmFormatModifierPlaneCount; ++i) {
             const Location drm_loc =
                 create_info_loc.pNext(Struct::VkImageDrmFormatModifierExplicitCreateInfoEXT, Field::pPlaneLayouts, i);
-            if (drm_format_mod_explict->pPlaneLayouts[i].size != 0) {
+            if (drm_format_mod_explicit->pPlaneLayouts[i].size != 0) {
                 skip |= LogError("VUID-VkImageDrmFormatModifierExplicitCreateInfoEXT-size-02267", device, drm_loc.dot(Field::size),
-                                 "is not zero (%" PRIu64 ").", drm_format_mod_explict->pPlaneLayouts[i].size);
+                                 "is not zero (%" PRIu64 ").", drm_format_mod_explicit->pPlaneLayouts[i].size);
             }
-            if (create_info.arrayLayers == 1 && drm_format_mod_explict->pPlaneLayouts[i].arrayPitch != 0) {
+            if (create_info.arrayLayers == 1 && drm_format_mod_explicit->pPlaneLayouts[i].arrayPitch != 0) {
                 skip |= LogError("VUID-VkImageDrmFormatModifierExplicitCreateInfoEXT-arrayPitch-02268", device,
                                  drm_loc.dot(Field::arrayPitch), "is %" PRIu64 " and arrayLayers is 1.",
-                                 drm_format_mod_explict->pPlaneLayouts[i].arrayPitch);
+                                 drm_format_mod_explicit->pPlaneLayouts[i].arrayPitch);
             }
-            if (create_info.extent.depth == 1 && drm_format_mod_explict->pPlaneLayouts[i].depthPitch != 0) {
+            if (create_info.extent.depth == 1 && drm_format_mod_explicit->pPlaneLayouts[i].depthPitch != 0) {
                 skip |= LogError("VUID-VkImageDrmFormatModifierExplicitCreateInfoEXT-depthPitch-02269", device,
                                  drm_loc.dot(Field::depthPitch), "is %" PRIu64 " and extext.depth is 1.",
-                                 drm_format_mod_explict->pPlaneLayouts[i].depthPitch);
+                                 drm_format_mod_explicit->pPlaneLayouts[i].depthPitch);
             }
         }
     }
 
     const auto compression_control = vku::FindStructInPNextChain<VkImageCompressionControlEXT>(create_info.pNext);
-    if (drm_format_mod_explict && compression_control) {
+    if (drm_format_mod_explicit && compression_control) {
         skip |= LogError("VUID-VkImageCreateInfo-pNext-06746", device, create_info_loc.dot(Field::pNext),
                          "has both VkImageCompressionControlEXT and VkImageDrmFormatModifierExplicitCreateInfoEXT.\n%s",
                          PrintPNextChain(Struct::VkImageCreateInfo, create_info.pNext).c_str());
@@ -899,7 +898,6 @@ bool Device::ValidateCreateImageDrmFormatModifiers(const VkImageCreateInfo &crea
 bool Device::ValidateImageViewCreateInfo(const VkImageViewCreateInfo &create_info, const Location &create_info_loc) const {
     bool skip = false;
 
-    // Validate feature set if using CUBE_ARRAY
     if ((create_info.viewType == VK_IMAGE_VIEW_TYPE_CUBE_ARRAY) && (!enabled_features.imageCubeArray)) {
         skip |= LogError("VUID-VkImageViewCreateInfo-viewType-01004", create_info.image, create_info_loc.dot(Field::viewType),
                          "is VK_IMAGE_VIEW_TYPE_CUBE_ARRAY but the imageCubeArray feature is not enabled.");
@@ -911,7 +909,8 @@ bool Device::ValidateImageViewCreateInfo(const VkImageViewCreateInfo &create_inf
                              create_info_loc.dot(Field::subresourceRange).dot(Field::layerCount),
                              "(%" PRIu32 ") must be 6 or VK_REMAINING_ARRAY_LAYERS.", create_info.subresourceRange.layerCount);
         }
-        if (create_info.viewType == VK_IMAGE_VIEW_TYPE_CUBE_ARRAY && (create_info.subresourceRange.layerCount % 6) != 0) {
+        if (create_info.viewType == VK_IMAGE_VIEW_TYPE_CUBE_ARRAY &&
+            !IsIntegerMultipleOf(create_info.subresourceRange.layerCount, 6)) {
             skip |= LogError("VUID-VkImageViewCreateInfo-viewType-02961", create_info.image,
                              create_info_loc.dot(Field::subresourceRange).dot(Field::layerCount),
                              "(%" PRIu32 ") must be a multiple of 6 or VK_REMAINING_ARRAY_LAYERS.",
@@ -953,6 +952,15 @@ bool Device::ValidateImageViewCreateInfo(const VkImageViewCreateInfo &create_inf
                                         create_info_loc, "VK_EXPORT_METAL_OBJECT_TYPE_METAL_TEXTURE_BIT_EXT", create_info.pNext);
 #endif  // VK_USE_PLATFORM_METAL_EXT
 
+    if (api_version < VK_API_VERSION_1_3 && !enabled_features.ycbcr2plane444Formats) {
+        if (IsValueIn(create_info.format,
+                      {VK_FORMAT_G8_B8R8_2PLANE_444_UNORM, VK_FORMAT_G10X6_B10X6R10X6_2PLANE_444_UNORM_3PACK16,
+                       VK_FORMAT_G12X4_B12X4R12X4_2PLANE_444_UNORM_3PACK16, VK_FORMAT_G16_B16R16_2PLANE_444_UNORM})) {
+            skip |= LogError("VUID-VkImageViewCreateInfo-None-12280", device, create_info_loc.dot(Field::format), "is %s.",
+                             string_VkFormat(create_info.format));
+        }
+    }
+
     return skip;
 }
 
@@ -1040,4 +1048,106 @@ bool Device::manual_PreCallValidateGetDeviceImageSubresourceLayout(VkDevice devi
 
     return skip;
 }
+
+bool Device::manual_PreCallValidateCmdResolveImage(VkCommandBuffer commandBuffer, VkImage srcImage, VkImageLayout srcImageLayout,
+                                                   VkImage dstImage, VkImageLayout dstImageLayout, uint32_t regionCount,
+                                                   const VkImageResolve *pRegions, const Context &context) const {
+    bool skip = false;
+
+    for (uint32_t i = 0; i < regionCount; i++) {
+        const Location region_loc = context.error_obj.location.dot(Field::pRegions, i);
+        const Location src_subresource_loc = region_loc.dot(Field::srcSubresource);
+        const Location dst_subresource_loc = region_loc.dot(Field::dstSubresource);
+
+        if (pRegions[i].srcSubresource.aspectMask != VK_IMAGE_ASPECT_COLOR_BIT) {
+            skip |= LogError("VUID-VkImageResolve-aspectMask-10981", commandBuffer, src_subresource_loc, "is %s.",
+                             string_VkImageAspectFlags(pRegions[i].srcSubresource.aspectMask).c_str());
+        }
+        if (pRegions[i].dstSubresource.aspectMask != VK_IMAGE_ASPECT_COLOR_BIT) {
+            skip |= LogError("VUID-VkImageResolve-aspectMask-10981", commandBuffer, dst_subresource_loc, "is %s.",
+                             string_VkImageAspectFlags(pRegions[i].dstSubresource.aspectMask).c_str());
+        }
+
+        if (pRegions[i].srcSubresource.aspectMask != pRegions[i].dstSubresource.aspectMask) {
+            skip |=
+                LogError("VUID-vkCmdResolveImage-srcSubresource-11802", commandBuffer, src_subresource_loc.dot(Field::aspectMask),
+                         "(%s) is not equal to %s (%s)", string_VkImageAspectFlags(pRegions[i].srcSubresource.aspectMask).c_str(),
+                         dst_subresource_loc.dot(Field::aspectMask).Fields().c_str(),
+                         string_VkImageAspectFlags(pRegions[i].dstSubresource.aspectMask).c_str());
+        }
+    }
+
+    return skip;
+}
+
+bool Device::manual_PreCallValidateCmdResolveImage2(VkCommandBuffer commandBuffer, const VkResolveImageInfo2 *pResolveImageInfo,
+                                                    const Context &context) const {
+    bool skip = false;
+    const Location resolve_info_loc = context.error_obj.location.dot(Field::pResolveImageInfo);
+    for (uint32_t i = 0; i < pResolveImageInfo->regionCount; i++) {
+        const Location region_loc = resolve_info_loc.dot(Field::pRegions, i);
+        const Location src_subresource_loc = region_loc.dot(Field::srcSubresource);
+        const Location dst_subresource_loc = region_loc.dot(Field::dstSubresource);
+        const VkImageResolve2 &region = pResolveImageInfo->pRegions[i];
+
+        if (enabled_features.maintenance10) {
+            if (region.srcSubresource.aspectMask &
+                ~(VK_IMAGE_ASPECT_COLOR_BIT | VK_IMAGE_ASPECT_DEPTH_BIT | VK_IMAGE_ASPECT_STENCIL_BIT)) {
+                skip |= LogError("VUID-VkImageResolve2-aspectMask-10993", commandBuffer, src_subresource_loc, "is %s.",
+                                 string_VkImageAspectFlags(region.srcSubresource.aspectMask).c_str());
+            }
+            if (region.dstSubresource.aspectMask &
+                ~(VK_IMAGE_ASPECT_COLOR_BIT | VK_IMAGE_ASPECT_DEPTH_BIT | VK_IMAGE_ASPECT_STENCIL_BIT)) {
+                skip |= LogError("VUID-VkImageResolve2-aspectMask-10993", commandBuffer, dst_subresource_loc, "is %s.",
+                                 string_VkImageAspectFlags(region.dstSubresource.aspectMask).c_str());
+            }
+        } else {
+            if (region.srcSubresource.aspectMask != VK_IMAGE_ASPECT_COLOR_BIT) {
+                skip |= LogError("VUID-VkImageResolve2-maintenance10-10994", commandBuffer, src_subresource_loc,
+                                 "is %s. (Having maintenance 10 feature enable would allow VK_IMAGE_ASPECT_DEPTH_BIT and "
+                                 "VK_IMAGE_ASPECT_STENCIL_BIT).",
+                                 string_VkImageAspectFlags(region.srcSubresource.aspectMask).c_str());
+            }
+            if (region.dstSubresource.aspectMask != VK_IMAGE_ASPECT_COLOR_BIT) {
+                skip |= LogError("VUID-VkImageResolve2-maintenance10-10994", commandBuffer, dst_subresource_loc,
+                                 "is %s. (Having maintenance 10 feature enable would allow VK_IMAGE_ASPECT_DEPTH_BIT and "
+                                 "VK_IMAGE_ASPECT_STENCIL_BIT).",
+                                 string_VkImageAspectFlags(region.dstSubresource.aspectMask).c_str());
+            }
+        }
+        if (region.srcSubresource.aspectMask != region.dstSubresource.aspectMask) {
+            skip |=
+                LogError("VUID-VkResolveImageInfo2-srcSubresource-11802", commandBuffer, src_subresource_loc.dot(Field::aspectMask),
+                         "(%s) is not equal to %s (%s)", string_VkImageAspectFlags(region.srcSubresource.aspectMask).c_str(),
+                         dst_subresource_loc.dot(Field::aspectMask).Fields().c_str(),
+                         string_VkImageAspectFlags(region.dstSubresource.aspectMask).c_str());
+        }
+    }
+
+    if (const auto *resolve_mode_info = vku::FindStructInPNextChain<VkResolveImageModeInfoKHR>(pResolveImageInfo->pNext)) {
+        const auto both_skip_and_enable_transfer_flags =
+            VK_RESOLVE_IMAGE_SKIP_TRANSFER_FUNCTION_BIT_KHR | VK_RESOLVE_IMAGE_ENABLE_TRANSFER_FUNCTION_BIT_KHR;
+        if ((resolve_mode_info->flags & both_skip_and_enable_transfer_flags) == both_skip_and_enable_transfer_flags) {
+            skip |= LogError("VUID-VkResolveImageModeInfoKHR-flags-10995", commandBuffer,
+                             resolve_info_loc.pNext(Struct::VkResolveImageModeInfoKHR, Field::flags), "is %s.",
+                             string_VkResolveImageFlagsKHR(resolve_mode_info->flags).c_str());
+        }
+
+        if ((resolve_mode_info->flags & both_skip_and_enable_transfer_flags)) {
+            if (!phys_dev_ext_props.maintenance10_props.resolveSrgbFormatSupportsTransferFunctionControl) {
+                skip |= LogError("VUID-VkResolveImageModeInfoKHR-flags-10996", commandBuffer,
+                                 resolve_info_loc.pNext(Struct::VkResolveImageModeInfoKHR, Field::flags),
+                                 "is %s but resolveSrgbFormatSupportsTransferFunctionControl is not supported on this device.",
+                                 string_VkResolveImageFlagsKHR(resolve_mode_info->flags).c_str());
+            }
+            if (resolve_mode_info->resolveMode != VK_RESOLVE_MODE_AVERAGE_BIT) {
+                skip |= LogError("VUID-VkResolveImageModeInfoKHR-flags-10997", commandBuffer,
+                                 resolve_info_loc.pNext(Struct::VkResolveImageModeInfoKHR, Field::resolveMode), "is %s.",
+                                 string_VkResolveModeFlagBits(resolve_mode_info->resolveMode));
+            }
+        }
+    }
+
+    return skip;
+}
 }  // namespace stateless
