@@ -1,6 +1,6 @@
-/* Copyright (c) 2019-2025 The Khronos Group Inc.
- * Copyright (c) 2019-2025 Valve Corporation
- * Copyright (c) 2019-2025 LunarG, Inc.
+/* Copyright (c) 2019-2026 The Khronos Group Inc.
+ * Copyright (c) 2019-2026 Valve Corporation
+ * Copyright (c) 2019-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -348,7 +348,7 @@ class AccessState {
     void Resolve(const AccessState &other);
 
     // Apply a single barrier to the access state
-    void ApplyBarrier(const BarrierScope &barrier_scope, const SyncBarrier &barrier, bool layout_transition = false,
+    bool ApplyBarrier(const BarrierScope &barrier_scope, const SyncBarrier &barrier, bool layout_transition = false,
                       uint32_t layout_transition_handle_index = vvl::kNoIndex32,
                       ResourceUsageTag layout_transition_tag = kInvalidTag);
 
@@ -366,29 +366,6 @@ class AccessState {
 
     void ApplySemaphore(const SemaphoreScope &signal, const SemaphoreScope &wait);
 
-    struct WaitQueueTagPredicate {
-        QueueId queue;
-        ResourceUsageTag tag;
-        bool operator()(const ReadState &read_access) const;       // Read access predicate
-        bool operator()(const AccessState &access) const;  // Write access predicate
-    };
-    friend WaitQueueTagPredicate;
-
-    struct WaitTagPredicate {
-        ResourceUsageTag tag;
-        bool operator()(const ReadState &read_access) const;       // Read access predicate
-        bool operator()(const AccessState &access) const;  // Write access predicate
-    };
-    friend WaitTagPredicate;
-
-    struct WaitAcquirePredicate {
-        ResourceUsageTag present_tag;
-        ResourceUsageTag acquire_tag;
-        bool operator()(const ReadState &read_access) const;       // Read access predicate
-        bool operator()(const AccessState &access) const;  // Write access predicate
-    };
-    friend WaitAcquirePredicate;
-
     // Clear read/write accesses that satisfy the predicate
     // (predicate says which accesses should be considered synchronized).
     // Return true if all accesses were cleared and access state is empty
@@ -457,6 +434,13 @@ class AccessState {
     void MergeReads(const AccessState &other);
     void ClearReadStates();
 
+public:
+    // Index of the next global barrier to apply.
+    // Global barriers are stored in the AccessContext associated with this access state.
+    // If 0, no global barriers have been applied yet.
+    // If greater than 0, then all global barriers with smaller indices are already applied.
+    uint32_t next_global_barrier_index = 0;
+
   private:
     // The most recent write.
     // NOTE: For reads, each must be "safe" relative to its prior write, so we need
