@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2019-2025 Valve Corporation
- * Copyright (c) 2019-2025 LunarG, Inc.
+ * Copyright (c) 2019-2026 Valve Corporation
+ * Copyright (c) 2019-2026 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -35,7 +35,6 @@ class Instance : public vvl::InstanceProxy {
   public:
     Instance(vvl::dispatch::Instance *dispatch) : vvl::InstanceProxy(dispatch, LayerObjectTypeSyncValidation) {}
 };
-}  // namespace syncval
 
 class SyncValidator : public vvl::DeviceProxy {
     using BaseClass = vvl::DeviceProxy;
@@ -48,12 +47,12 @@ class SyncValidator : public vvl::DeviceProxy {
     SyncValidator(vvl::dispatch::Device *dev, syncval::Instance *instance_vo);
     ~SyncValidator();
 
-    syncval::ErrorMessages error_messages_;
+    ErrorMessages error_messages_;
 
     // Stats object must be the first member of this class:
     // - it is the first to be constructed: can observe all subsequent syncval stats events
     // - it is the last to be destroyed: ensures there are no unreported syncval stats events.
-    mutable syncval_stats::Stats stats;  // Stats object is thread safe
+    mutable Stats stats;  // Stats object is thread safe
     const bool report_stats_ = false;
 
     // Global tag range for submitted command buffers resource usage logs
@@ -74,7 +73,7 @@ class SyncValidator : public vvl::DeviceProxy {
     vvl::unordered_map<VkFence, FenceHostSyncPoint> waitable_fences_;
     vvl::unordered_map<VkSemaphore, std::deque<TimelineHostSyncPoint>> host_waitable_semaphores_;
 
-    uint32_t debug_command_number = vvl::kU32Max;
+    uint32_t debug_command_number = vvl::kNoIndex32;
     uint32_t debug_reset_count = 1;
     std::string debug_cmdbuf_pattern;
 
@@ -103,7 +102,8 @@ class SyncValidator : public vvl::DeviceProxy {
     bool ProcessUnresolvedBatch(UnresolvedBatch &unresolved_batch, SignalsUpdate &signals_update, BatchContextPtr &last_batch,
                                 bool &skip, const ErrorObject &error_obj) const;
 
-    void ApplyTaggedWait(QueueId queue_id, ResourceUsageTag tag, const LastSynchronizedPresent &last_synchronized_present);
+    void ApplyTaggedWait(QueueId queue_id, ResourceUsageTag tag, const LastSynchronizedPresent &last_synchronized_present,
+                         const std::vector<ResourceUsageTag> &queue_sync_tags);
     void ApplyAcquireWait(const AcquiredImage &acquired);
 
     std::vector<QueueBatchContext::Ptr> GetAllQueueBatchContexts();
@@ -121,7 +121,8 @@ class SyncValidator : public vvl::DeviceProxy {
 
     std::vector<QueueBatchContext::ConstPtr> GetLastBatches(std::function<bool(const QueueBatchContext::ConstPtr &)> filter) const;
     std::vector<QueueBatchContext::Ptr> GetLastBatches(std::function<bool(const QueueBatchContext::ConstPtr &)> filter);
-    std::vector<QueueBatchContext::ConstPtr> GetLastPendingBatches(std::function<bool(const QueueBatchContext::ConstPtr &)> filter) const;
+    std::vector<QueueBatchContext::ConstPtr> GetLastPendingBatches(
+        std::function<bool(const QueueBatchContext::ConstPtr &)> filter) const;
     void ClearPending() const;
 
     void Created(vvl::CommandBuffer &cb_state) override;
@@ -140,8 +141,8 @@ class SyncValidator : public vvl::DeviceProxy {
 
     void FinishDeviceSetup(const VkDeviceCreateInfo *pCreateInfo, const Location &loc) override;
 
-    void PreCallRecordDestroyDevice(VkDevice device, const VkAllocationCallbacks* pAllocator,
-                                    const RecordObject& record_obj) override;
+    void PreCallRecordDestroyDevice(VkDevice device, const VkAllocationCallbacks *pAllocator,
+                                    const RecordObject &record_obj) override;
 
     void PostCallRecordCreateSemaphore(VkDevice device, const VkSemaphoreCreateInfo *pCreateInfo,
                                        const VkAllocationCallbacks *pAllocator, VkSemaphore *pSemaphore,
@@ -519,11 +520,10 @@ class SyncValidator : public vvl::DeviceProxy {
                                                 const RecordObject &record_obj) override;
     void PostCallRecordGetSemaphoreCounterValueKHR(VkDevice device, VkSemaphore semaphore, uint64_t *pValue,
                                                    const RecordObject &record_obj) override;
-    void PostCallRecordGetSwapchainImagesKHR(VkDevice device, VkSwapchainKHR swapchain, uint32_t *pSwapchainImageCount,
-                                             VkImage *pSwapchainImages, const RecordObject &record_obj) override;
-    bool PreCallValidateCmdBuildAccelerationStructuresKHR(
-        VkCommandBuffer commandBuffer, uint32_t infoCount, const VkAccelerationStructureBuildGeometryInfoKHR *pInfos,
-        const VkAccelerationStructureBuildRangeInfoKHR *const *ppBuildRangeInfos, const ErrorObject &error_obj) const override;
+    bool PreCallValidateCmdBuildAccelerationStructuresKHR(VkCommandBuffer commandBuffer, uint32_t infoCount,
+                                                          const VkAccelerationStructureBuildGeometryInfoKHR *pInfos,
+                                                          const VkAccelerationStructureBuildRangeInfoKHR *const *ppBuildRangeInfos,
+                                                          const ErrorObject &error_obj) const override;
     void PostCallRecordCmdBuildAccelerationStructuresKHR(VkCommandBuffer commandBuffer, uint32_t infoCount,
                                                          const VkAccelerationStructureBuildGeometryInfoKHR *pInfos,
                                                          const VkAccelerationStructureBuildRangeInfoKHR *const *ppBuildRangeInfos,
@@ -575,3 +575,5 @@ class SyncValidator : public vvl::DeviceProxy {
     void PostCallRecordCmdTraceRaysIndirect2KHR(VkCommandBuffer commandBuffer, VkDeviceAddress indirectDeviceAddress,
                                                 const RecordObject &record_obj) override;
 };
+
+}  // namespace syncval
