@@ -122,9 +122,9 @@ void RayTracingPipelineHelper::InitShaderInfo() {  // DONE
         }
     )glsl";
 
-    rgs_ = std::make_unique<VkShaderObj>(&layer_test_, rayGenShaderText, VK_SHADER_STAGE_RAYGEN_BIT_NV);
-    chs_ = std::make_unique<VkShaderObj>(&layer_test_, closestHitShaderText, VK_SHADER_STAGE_CLOSEST_HIT_BIT_NV);
-    mis_ = std::make_unique<VkShaderObj>(&layer_test_, missShaderText, VK_SHADER_STAGE_MISS_BIT_NV);
+    rgs_ = std::make_unique<VkShaderObj>(*layer_test_.DeviceObj(), rayGenShaderText, VK_SHADER_STAGE_RAYGEN_BIT_NV);
+    chs_ = std::make_unique<VkShaderObj>(*layer_test_.DeviceObj(), closestHitShaderText, VK_SHADER_STAGE_CLOSEST_HIT_BIT_NV);
+    mis_ = std::make_unique<VkShaderObj>(*layer_test_.DeviceObj(), missShaderText, VK_SHADER_STAGE_MISS_BIT_NV);
 
     shader_stages_ = {rgs_->GetStageCreateInfo(), chs_->GetStageCreateInfo(), mis_->GetStageCreateInfo()};
 }
@@ -139,7 +139,7 @@ void RayTracingPipelineHelper::InitNVRayTracingPipelineInfo() {
 }
 
 void RayTracingPipelineHelper::AddLibrary(const RayTracingPipelineHelper &library) {
-    libraries_.emplace_back(library.Handle());
+    libraries_.emplace_back(library);
     rp_library_ci_ = vku::InitStructHelper();
     rp_library_ci_.libraryCount = size32(libraries_);
     rp_library_ci_.pLibraries = libraries_.data();
@@ -178,11 +178,11 @@ void RayTracingPipelineHelper::LateBindPipelineInfo(bool isKHR) {
     pipeline_layout_ = vkt::PipelineLayout(*layer_test_.DeviceObj(), {&descriptor_set_->layout_});
 
     if (isKHR) {
-        rp_ci_KHR_.layout = pipeline_layout_.handle();
+        rp_ci_KHR_.layout = pipeline_layout_;
         rp_ci_KHR_.stageCount = shader_stages_.size();
         rp_ci_KHR_.pStages = shader_stages_.data();
     } else {
-        rp_ci_.layout = pipeline_layout_.handle();
+        rp_ci_.layout = pipeline_layout_;
         rp_ci_.stageCount = shader_stages_.size();
         rp_ci_.pStages = shader_stages_.data();
     }
