@@ -1,8 +1,8 @@
 /*
- * Copyright (c) 2015-2025 The Khronos Group Inc.
- * Copyright (c) 2015-2025 Valve Corporation
- * Copyright (c) 2015-2025 LunarG, Inc.
- * Copyright (c) 2015-2025 Google, Inc.
+ * Copyright (c) 2015-2026 The Khronos Group Inc.
+ * Copyright (c) 2015-2026 Valve Corporation
+ * Copyright (c) 2015-2026 LunarG, Inc.
+ * Copyright (c) 2015-2026 Google, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -354,7 +354,7 @@ bool VkRenderFramework::IsExtensionsEnabled(const char *ext_name) const {
 }
 
 std::string VkRenderFramework::RequiredExtensionsNotSupported() const {
-    std::stringstream ss;
+    std::ostringstream ss;
     bool first = true;
     for (const auto &ext : m_required_extensions) {
         if (!CanEnableDeviceExtension(ext) && !CanEnableInstanceExtension(ext)) {
@@ -698,6 +698,10 @@ void VkRenderFramework::InitState(VkPhysicalDeviceFeatures *features, void *crea
         m_third_queue = queues[2];
         m_third_queue_caps = m_device->Physical().queue_properties_[m_third_queue->family_index].queueFlags;
     }
+    if (queues.size() > 3) {
+        m_fourth_queue = queues[3];
+        m_fourth_queue_caps = m_device->Physical().queue_properties_[m_fourth_queue->family_index].queueFlags;
+    }
 
     m_depthStencil = new vkt::Image();
 
@@ -720,7 +724,7 @@ void VkRenderFramework::InitSurface() {
     if (result != VK_SUCCESS) {
         GTEST_SKIP() << "Failed to create surface.";
     }
-    ASSERT_TRUE(m_surface.Handle() != VK_NULL_HANDLE);
+    ASSERT_TRUE(m_surface != VK_NULL_HANDLE);
 }
 
 #ifdef VK_USE_PLATFORM_WIN32_KHR
@@ -857,7 +861,7 @@ void SurfaceContext::Destroy() {
 
 // Queries the info needed to create a swapchain and assigns it to the member variables of VkRenderFramework
 void VkRenderFramework::InitSwapchainInfo() {
-    auto info = GetSwapchainInfo(m_surface.Handle());
+    auto info = GetSwapchainInfo(m_surface);
     m_surface_capabilities = info.surface_capabilities;
     m_surface_formats = info.surface_formats;
     m_surface_present_modes = info.surface_present_modes;
@@ -934,7 +938,7 @@ VkSwapchainCreateInfoKHR VkRenderFramework::GetDefaultSwapchainCreateInfo(VkSurf
 void VkRenderFramework::InitSwapchain(VkImageUsageFlags image_usage) {
     RETURN_IF_SKIP(InitSurface());
     InitSwapchainInfo();
-    m_swapchain = CreateSwapchain(m_surface.Handle(), image_usage, VK_SURFACE_TRANSFORM_IDENTITY_BIT_KHR);
+    m_swapchain = CreateSwapchain(m_surface, image_usage, VK_SURFACE_TRANSFORM_IDENTITY_BIT_KHR);
     ASSERT_TRUE(m_swapchain.initialized());
 }
 
