@@ -177,7 +177,7 @@ TEST_F(StressGpuAV, DescriptorIndexing) {
     )glsl";
 
     CreateComputePipelineHelper pipe(*this);
-    pipe.cs_ = VkShaderObj(this, cs_source, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
+    pipe.cs_ = VkShaderObj(*m_device, cs_source, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
     pipe.cp_ci_.layout = pipeline_layout;
     pipe.CreateComputePipeline();
 
@@ -209,7 +209,7 @@ TEST_F(StressGpuAV, DescriptorIndexing2) {
     //         x[1].bn = floatBitsToUint(a * n);
     //     }
     const uint32_t field_count = 100;
-    std::stringstream cs_source;
+    std::ostringstream cs_source;
     cs_source << R"glsl(
         #version 450
         layout(set = 0, binding = 0) buffer SSBO {
@@ -241,7 +241,7 @@ TEST_F(StressGpuAV, DescriptorIndexing2) {
     descriptor_set.UpdateDescriptorSets();
 
     CreateComputePipelineHelper pipe(*this);
-    pipe.cs_ = VkShaderObj(this, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
+    pipe.cs_ = VkShaderObj(*m_device, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
     pipe.cp_ci_.layout = pipeline_layout;
     pipe.CreateComputePipeline();
 
@@ -267,7 +267,7 @@ TEST_F(StressGpuAV, DescriptorIndexingPushConstantAccess) {
     const vkt::PipelineLayout pipeline_layout(*m_device, {&descriptor_set.layout_}, {pc_range});
 
     const uint32_t count = 150;
-    std::stringstream cs_source;
+    std::ostringstream cs_source;
     cs_source << R"glsl(
         #version 450
         #extension GL_EXT_buffer_reference2 : require
@@ -297,7 +297,7 @@ TEST_F(StressGpuAV, DescriptorIndexingPushConstantAccess) {
     cs_source << "\n}";
 
     CreateComputePipelineHelper pipe(*this);
-    pipe.cs_ = VkShaderObj(this, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
+    pipe.cs_ = VkShaderObj(*m_device, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
     pipe.cp_ci_.layout = pipeline_layout;
     pipe.CreateComputePipeline();
 }
@@ -340,7 +340,7 @@ TEST_F(StressGpuAV, DescriptorIndexingLoop) {
     descriptor_set.UpdateDescriptorSets();
 
     CreateComputePipelineHelper pipe(*this);
-    pipe.cs_ = VkShaderObj(this, cs_source, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_0);
+    pipe.cs_ = VkShaderObj(*m_device, cs_source, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_0);
     pipe.cp_ci_.layout = pipeline_layout;
     pipe.CreateComputePipeline();
 
@@ -372,7 +372,7 @@ TEST_F(StressGpuAV, DescriptorIndexingGeneralBufferOOB) {
     //     a += dot(vec4(m[31].x, m[31].y, m[31].z, m[31].w), b);
     // }
     const uint32_t array_count = 32;
-    std::stringstream cs_source;
+    std::ostringstream cs_source;
     cs_source << R"glsl(
         #version 450
         layout(set = 0, binding = 0) buffer SSBO {
@@ -399,7 +399,7 @@ TEST_F(StressGpuAV, DescriptorIndexingGeneralBufferOOB) {
     descriptor_set.UpdateDescriptorSets();
 
     CreateComputePipelineHelper pipe(*this);
-    pipe.cs_ = VkShaderObj(this, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
+    pipe.cs_ = VkShaderObj(*m_device, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_2);
     pipe.cp_ci_.layout = pipeline_layout;
     pipe.CreateComputePipeline();
 
@@ -424,7 +424,7 @@ TEST_F(StressGpuAV, BufferDeviceAddress) {
     InitRenderTarget();
     const uint32_t count = 32;
 
-    std::stringstream cs_source;
+    std::ostringstream cs_source;
     cs_source << R"glsl(
         #version 450
         #extension GL_EXT_buffer_reference : enable
@@ -461,6 +461,6 @@ TEST_F(StressGpuAV, BufferDeviceAddress) {
 
     CreateComputePipelineHelper pipe(*this);
     pipe.cp_ci_.layout = pipeline_layout;
-    pipe.cs_ = VkShaderObj(this, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT);
+    pipe.cs_ = VkShaderObj(*m_device, cs_source.str().c_str(), VK_SHADER_STAGE_COMPUTE_BIT);
     pipe.CreateComputePipeline();
 }
\ No newline at end of file
