@@ -43,7 +43,7 @@ TEST_F(VkAmdBestPracticesLayerTest, TooManyPipelines) {
         }
         CreatePipelineHelper pipe(*this);
         pipe.CreateGraphicsPipeline();
-        pipeline_Array[i] = pipe.Handle();
+        pipeline_Array[i] = pipe;
         if (i == 1) {
             // change check to too many pipelines
             m_errorMonitor->VerifyFound();
@@ -509,7 +509,7 @@ TEST_F(VkAmdBestPracticesLayerTest, ComputeWorkgroupSize) {
 
     // workgroup size = 4
     {
-        VkShaderObj compute_4_1_1(this,
+        VkShaderObj compute_4_1_1(*m_device,
                                   "#version 320 es\n"
                                   "\n"
                                   "layout(local_size_x = 4, local_size_y = 1, local_size_z = 1) in;\n\n"
@@ -524,7 +524,7 @@ TEST_F(VkAmdBestPracticesLayerTest, ComputeWorkgroupSize) {
 
     // workgroup size = 64
     {
-        VkShaderObj compute_8_8_1(this,
+        VkShaderObj compute_8_8_1(*m_device,
                                   "#version 320 es\n"
                                   "\n"
                                   "layout(local_size_x = 8, local_size_y = 8, local_size_z = 1) in;\n\n"
@@ -537,7 +537,7 @@ TEST_F(VkAmdBestPracticesLayerTest, ComputeWorkgroupSize) {
 
     // workgroup size = 128
     {
-        VkShaderObj compute_16_8_1(this,
+        VkShaderObj compute_16_8_1(*m_device,
                                    "#version 320 es\n"
                                    "\n"
                                    "layout(local_size_x = 16, local_size_y = 8, local_size_z = 1) in;\n\n"
