@@ -162,11 +162,11 @@ TEST_F(PositiveDebugExtensions, SwapchainImagesDebugMarker) {
     RETURN_IF_SKIP(Init());
     RETURN_IF_SKIP(InitSurface());
 
-    SurfaceInformation info = GetSwapchainInfo(m_surface.Handle());
+    SurfaceInformation info = GetSwapchainInfo(m_surface);
     InitSwapchainInfo();
 
     VkSwapchainCreateInfoKHR swapchain_create_info = vku::InitStructHelper();
-    swapchain_create_info.surface = m_surface.Handle();
+    swapchain_create_info.surface = m_surface;
     swapchain_create_info.minImageCount = info.surface_capabilities.minImageCount;
     swapchain_create_info.imageFormat = info.surface_formats[0].format;
     swapchain_create_info.imageColorSpace = info.surface_formats[0].colorSpace;
