@@ -16,6 +16,7 @@
 #include "../framework/buffer_helper.h"
 #include "../framework/ray_tracing_objects.h"
 #include "../framework/shader_object_helper.h"
+#include "shader_templates.h"
 
 class PositiveGpuAVIndirectBuffer : public GpuAVTest {};
 
@@ -146,19 +147,7 @@ TEST_F(PositiveGpuAVIndirectBuffer, Mesh) {
     uint32_t *count_ptr = static_cast<uint32_t *>(count_buffer.Memory().Map());
     *count_ptr = 3;
 
-    const char *mesh_shader_source = R"glsl(
-        #version 450
-        #extension GL_EXT_mesh_shader : require
-        layout(local_size_x = 1, local_size_y = 1, local_size_z = 1) in;
-        layout(max_vertices = 3, max_primitives = 1) out;
-        layout(triangles) out;
-        struct Task {
-            uint baseID;
-        };
-        taskPayloadSharedEXT Task IN;
-        void main() {}
-    )glsl";
-    VkShaderObj mesh_shader(this, mesh_shader_source, VK_SHADER_STAGE_MESH_BIT_EXT, SPV_ENV_VULKAN_1_3);
+    VkShaderObj mesh_shader(*m_device, kMeshMinimalGlsl, VK_SHADER_STAGE_MESH_BIT_EXT, SPV_ENV_VULKAN_1_3);
     CreatePipelineHelper mesh_pipe(*this);
     mesh_pipe.shader_stages_[0] = mesh_shader.GetStageCreateInfo();
     mesh_pipe.CreateGraphicsPipeline();
@@ -207,19 +196,8 @@ TEST_F(PositiveGpuAVIndirectBuffer, MeshSingleCommand) {
     vkt::Buffer count_buffer(*m_device, sizeof(uint32_t), VK_BUFFER_USAGE_INDIRECT_BUFFER_BIT, kHostVisibleMemProps);
     uint32_t *count_ptr = static_cast<uint32_t *>(count_buffer.Memory().Map());
     *count_ptr = 3;
-    const char *mesh_shader_source = R"glsl(
-        #version 450
-        #extension GL_EXT_mesh_shader : require
-        layout(local_size_x = 1, local_size_y = 1, local_size_z = 1) in;
-        layout(max_vertices = 3, max_primitives = 1) out;
-        layout(triangles) out;
-        struct Task {
-            uint baseID;
-        };
-        taskPayloadSharedEXT Task IN;
-        void main() {}
-    )glsl";
-    VkShaderObj mesh_shader(this, mesh_shader_source, VK_SHADER_STAGE_MESH_BIT_EXT, SPV_ENV_VULKAN_1_3);
+
+    VkShaderObj mesh_shader(*m_device, kMeshMinimalGlsl, VK_SHADER_STAGE_MESH_BIT_EXT, SPV_ENV_VULKAN_1_3);
     CreatePipelineHelper mesh_pipe(*this);
     mesh_pipe.shader_stages_[0] = mesh_shader.GetStageCreateInfo();
     mesh_pipe.CreateGraphicsPipeline();
@@ -352,12 +330,12 @@ TEST_F(PositiveGpuAVIndirectBuffer, RestoreStress) {
     g_descriptor_set.UpdateDescriptorSets();
 
     CreateComputePipelineHelper c_pipe(*this);
-    c_pipe.cs_ = VkShaderObj(this, shader_source, VK_SHADER_STAGE_COMPUTE_BIT);
+    c_pipe.cs_ = VkShaderObj(*m_device, shader_source, VK_SHADER_STAGE_COMPUTE_BIT);
     c_pipe.cp_ci_.layout = c_pipeline_layout;
     c_pipe.CreateComputePipeline();
 
-    VkShaderObj vs(this, shader_source, VK_SHADER_STAGE_VERTEX_BIT);
-    VkShaderObj fs(this, shader_source, VK_SHADER_STAGE_FRAGMENT_BIT);
+    VkShaderObj vs(*m_device, shader_source, VK_SHADER_STAGE_VERTEX_BIT);
+    VkShaderObj fs(*m_device, shader_source, VK_SHADER_STAGE_FRAGMENT_BIT);
 
     VkFormat color_formats = VK_FORMAT_B8G8R8A8_UNORM;
     VkPipelineRenderingCreateInfo pipeline_rendering_info = vku::InitStructHelper();
