@@ -143,7 +143,7 @@ TEST_F(NegativeParent, BindPipeline) {
     pipeline_layout_ci.setLayoutCount = 0;
     vkt::PipelineLayout pipeline_layout(*m_second_device, pipeline_layout_ci);
 
-    VkShaderObj cs(this, kMinimalShaderGlsl, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
+    VkShaderObj cs(*m_device, kMinimalShaderGlsl, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
     cs.InitFromGLSLTry(m_second_device);
 
     VkComputePipelineCreateInfo pipeline_ci = vku::InitStructHelper();
@@ -167,7 +167,7 @@ TEST_F(NegativeParent, PipelineShaderStageCreateInfo) {
     pipeline_layout_ci.setLayoutCount = 0;
     vkt::PipelineLayout pipeline_layout(*m_device, pipeline_layout_ci);
 
-    VkShaderObj cs(this, kMinimalShaderGlsl, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
+    VkShaderObj cs(*m_device, kMinimalShaderGlsl, VK_SHADER_STAGE_COMPUTE_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
     cs.InitFromGLSLTry(m_second_device);
 
     VkComputePipelineCreateInfo pipeline_ci = vku::InitStructHelper();
@@ -298,7 +298,7 @@ TEST_F(NegativeParent, Instance_PhysicalDeviceAndSurface) {
 
     VkBool32 supported = VK_FALSE;
     m_errorMonitor->SetDesiredError("VUID-vkGetPhysicalDeviceSurfaceSupportKHR-commonparent");
-    vk::GetPhysicalDeviceSurfaceSupportKHR(Gpu(), m_device->graphics_queue_node_index_, instance2_surface.Handle(), &supported);
+    vk::GetPhysicalDeviceSurfaceSupportKHR(Gpu(), m_device->graphics_queue_node_index_, instance2_surface, &supported);
     m_errorMonitor->VerifyFound();
 }
 
@@ -316,7 +316,7 @@ TEST_F(NegativeParent, Instance_DeviceAndSurface) {
 
     VkDeviceGroupPresentModeFlagsKHR flags = 0;
     m_errorMonitor->SetDesiredError("VUID-vkGetDeviceGroupSurfacePresentModesKHR-commonparent");
-    vk::GetDeviceGroupSurfacePresentModesKHR(*m_device, instance2_surface.Handle(), &flags);
+    vk::GetDeviceGroupSurfacePresentModesKHR(*m_device, instance2_surface, &flags);
     m_errorMonitor->VerifyFound();
 }
 
@@ -336,7 +336,7 @@ TEST_F(NegativeParent, Instance_Surface) {
     }
 
     auto swapchain_ci = vku::InitStruct<VkSwapchainCreateInfoKHR>();
-    swapchain_ci.surface = instance2_surface.Handle();
+    swapchain_ci.surface = instance2_surface;
     swapchain_ci.minImageCount = m_surface_capabilities.minImageCount;
     swapchain_ci.imageFormat = m_surface_formats[0].format;
     swapchain_ci.imageColorSpace = m_surface_formats[0].colorSpace;
@@ -383,7 +383,7 @@ TEST_F(NegativeParent, Device_OldSwapchain) {
     vkt::Device instance2_device(instance2_physical_device, m_device_extension_names);
 
     auto swapchain_ci = vku::InitStruct<VkSwapchainCreateInfoKHR>();
-    swapchain_ci.surface = instance2_surface.Handle();
+    swapchain_ci.surface = instance2_surface;
     swapchain_ci.minImageCount = m_surface_capabilities.minImageCount;
     swapchain_ci.imageFormat = m_surface_formats[0].format;
     swapchain_ci.imageColorSpace = m_surface_formats[0].colorSpace;
@@ -400,7 +400,7 @@ TEST_F(NegativeParent, Device_OldSwapchain) {
     vkt::Swapchain other_device_swapchain(instance2_device, swapchain_ci);
 
     // oldSwapchain from a different device
-    swapchain_ci.surface = m_surface.Handle();
+    swapchain_ci.surface = m_surface;
     swapchain_ci.oldSwapchain = other_device_swapchain;
     m_errorMonitor->SetDesiredError("VUID-VkSwapchainCreateInfoKHR-commonparent");
     vkt::Swapchain swapchain(*m_device, swapchain_ci);
@@ -421,7 +421,7 @@ TEST_F(NegativeParent, Instance_Surface_2) {
 
     // surface from a different instance
     m_errorMonitor->SetDesiredError("VUID-vkDestroySurfaceKHR-surface-parent");
-    vk::DestroySurfaceKHR(instance(), instance2_surface.Handle(), nullptr);
+    vk::DestroySurfaceKHR(instance(), instance2_surface, nullptr);
     m_errorMonitor->VerifyFound();
 }
 
@@ -748,6 +748,35 @@ TEST_F(NegativeParent, UpdateDescriptorSetsCombinedImageSampler) {
     m_errorMonitor->VerifyFound();
 }
 
+TEST_F(NegativeParent, UpdateDescriptorSetsTensor) {
+    TEST_DESCRIPTION("Try to update tensor descriptors on the wrong device.");
+    SetTargetApiVersion(VK_API_VERSION_1_4);
+    AddRequiredExtensions(VK_ARM_TENSORS_EXTENSION_NAME);
+    AddRequiredFeature(vkt::Feature::tensors);
+    RETURN_IF_SKIP(Init());
+
+    // tensor and view allocated on the main device (m_device)
+    vkt::Tensor tensor(*m_device);
+    tensor.BindToMem();
+    VkTensorViewCreateInfoARM tensor_view_create_info = vku::InitStructHelper();
+    tensor_view_create_info.tensor = tensor;
+    tensor_view_create_info.format = tensor.Format();
+    vkt::TensorView view(*m_device, tensor_view_create_info);
+
+    // allocate the descriptor set on a different device (m_second_device)
+    auto features = m_device->Physical().Features();
+    m_second_device = new vkt::Device(gpu_, m_device_extension_names, &features, nullptr);
+    OneOffDescriptorSet descriptor_set(m_second_device,
+                                       {
+                                           {0, VK_DESCRIPTOR_TYPE_TENSOR_ARM, 1, VK_SHADER_STAGE_ALL, nullptr},
+                                       });
+    descriptor_set.WriteDescriptorTensorInfo(0, &view.handle(), 0);
+
+    m_errorMonitor->SetDesiredError("VUID-vkUpdateDescriptorSets-pDescriptorWrites-12324");
+    descriptor_set.UpdateDescriptorSets();
+    m_errorMonitor->VerifyFound();
+}
+
 TEST_F(NegativeParent, DescriptorSetLayout) {
     TEST_DESCRIPTION("Create pipeline layout from a descriptor set layout that was created on a different device");
     RETURN_IF_SKIP(Init());
