@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 2023-2024 The Khronos Group Inc.
- * Copyright (c) 2023-2024 Valve Corporation
- * Copyright (c) 2023-2024 LunarG, Inc.
+ * Copyright (c) 2023-2025 The Khronos Group Inc.
+ * Copyright (c) 2023-2025 Valve Corporation
+ * Copyright (c) 2023-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -10,7 +10,6 @@
  *     http://www.apache.org/licenses/LICENSE-2.0
  */
 
-#include "utils/cast_utils.h"
 #include "../framework/layer_validation_tests.h"
 #include "../framework/pipeline_helper.h"
 
@@ -21,44 +20,47 @@ TEST_F(NegativeRobustness, PipelineRobustnessDisabled) {
 
     SetTargetApiVersion(VK_API_VERSION_1_1);
     AddRequiredExtensions(VK_EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME);
+    AddRequiredExtensions(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME);
+    AddRequiredFeature(vkt::Feature::robustBufferAccess);
+    AddRequiredFeature(vkt::Feature::robustBufferAccess2);
     RETURN_IF_SKIP(Init());
 
     {
-        VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
-        pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+        VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
+        pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
         CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
 
-        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-pipelineRobustness-06926");
+        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-pipelineRobustness-06926");
         pipe.CreateComputePipeline();
         m_errorMonitor->VerifyFound();
     }
 
     {
-        VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
-        pipeline_robustness_info.uniformBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+        VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
+        pipeline_robustness_info.uniformBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
         CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
 
-        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-pipelineRobustness-06927");
+        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-pipelineRobustness-06927");
         pipe.CreateComputePipeline();
         m_errorMonitor->VerifyFound();
     }
 
     {
-        VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
-        pipeline_robustness_info.vertexInputs = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+        VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
+        pipeline_robustness_info.vertexInputs = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
         CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
 
-        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-pipelineRobustness-06928");
+        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-pipelineRobustness-06928");
         pipe.CreateComputePipeline();
         m_errorMonitor->VerifyFound();
     }
 
     {
-        VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
-        pipeline_robustness_info.images = VK_PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_2_EXT;
+        VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
+        pipeline_robustness_info.images = VK_PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_2;
         CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
 
-        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-pipelineRobustness-06929");
+        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-pipelineRobustness-06929");
         pipe.CreateComputePipeline();
         m_errorMonitor->VerifyFound();
     }
@@ -69,17 +71,20 @@ TEST_F(NegativeRobustness, PipelineRobustnessDisabledShaderStage) {
 
     SetTargetApiVersion(VK_API_VERSION_1_1);
     AddRequiredExtensions(VK_EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME);
+    AddRequiredExtensions(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME);
+    AddRequiredFeature(vkt::Feature::robustBufferAccess);
+    AddRequiredFeature(vkt::Feature::robustBufferAccess2);
     RETURN_IF_SKIP(Init());
 
     CreateComputePipelineHelper pipe(*this);
 
     pipe.LateBindPipelineInfo();
 
-    VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
-    pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+    VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
+    pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
     pipe.cp_ci_.stage.pNext = &pipeline_robustness_info;
 
-    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-pipelineRobustness-06926");
+    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-pipelineRobustness-06926");
     pipe.CreateComputePipeline(false);
     m_errorMonitor->VerifyFound();
 }
@@ -90,50 +95,48 @@ TEST_F(NegativeRobustness, PipelineRobustnessDisabledShaderStageWithIdentifier)
     SetTargetApiVersion(VK_API_VERSION_1_1);
     AddRequiredExtensions(VK_EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME);
     AddRequiredExtensions(VK_EXT_SHADER_MODULE_IDENTIFIER_EXTENSION_NAME);
-    RETURN_IF_SKIP(InitFramework());
-
-    VkPhysicalDevicePipelineCreationCacheControlFeatures shader_cache_control_features = vku::InitStructHelper();
-    VkPhysicalDeviceShaderModuleIdentifierFeaturesEXT shader_module_id_features =
-        vku::InitStructHelper(&shader_cache_control_features);
-    GetPhysicalDeviceFeatures2(shader_module_id_features);
-    RETURN_IF_SKIP(InitState(nullptr, &shader_module_id_features));
+    AddRequiredExtensions(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME);
+    AddRequiredFeature(vkt::Feature::pipelineCreationCacheControl);
+    AddRequiredFeature(vkt::Feature::shaderModuleIdentifier);
+    AddRequiredFeature(vkt::Feature::robustBufferAccess);
+    AddRequiredFeature(vkt::Feature::robustBufferAccess2);
+    RETURN_IF_SKIP(Init());
 
     CreateComputePipelineHelper pipe(*this);
 
     pipe.LateBindPipelineInfo();
 
     VkPipelineShaderStageModuleIdentifierCreateInfoEXT sm_id_create_info = vku::InitStructHelper();
-    VkShaderObj cs(this, kMinimalShaderGlsl, VK_SHADER_STAGE_COMPUTE_BIT);
+    VkShaderObj cs(*m_device, kMinimalShaderGlsl, VK_SHADER_STAGE_COMPUTE_BIT);
 
     VkShaderModuleIdentifierEXT get_identifier = vku::InitStructHelper();
-    vk::GetShaderModuleIdentifierEXT(device(), cs.handle(), &get_identifier);
+    vk::GetShaderModuleIdentifierEXT(device(), cs, &get_identifier);
     sm_id_create_info.identifierSize = get_identifier.identifierSize;
     sm_id_create_info.pIdentifier = get_identifier.identifier;
 
-    VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper(&sm_id_create_info);
-    pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+    VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper(&sm_id_create_info);
+    pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
     pipe.cp_ci_.stage.module = VK_NULL_HANDLE;
     pipe.cp_ci_.stage.pNext = &pipeline_robustness_info;
     pipe.cp_ci_.flags |= VK_PIPELINE_CREATE_FAIL_ON_PIPELINE_COMPILE_REQUIRED_BIT;
 
-    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-pipelineRobustness-06926");
+    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-pipelineRobustness-06926");
     pipe.CreateComputePipeline(false);
     m_errorMonitor->VerifyFound();
 }
 
-// Need to fix check to check if feature is exposed
-// TODO - https://github.com/KhronosGroup/Vulkan-ValidationLayers/issues/5657
-TEST_F(NegativeRobustness, DISABLED_PipelineRobustnessRobustBufferAccess2Unsupported) {
+TEST_F(NegativeRobustness, PipelineRobustnessRobustBufferAccess2Unsupported) {
     TEST_DESCRIPTION("Create a pipeline using VK_EXT_pipeline_robustness with robustBufferAccess2 being unsupported");
 
     SetTargetApiVersion(VK_API_VERSION_1_1);
     AddRequiredExtensions(VK_EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME);
+    AddOptionalExtensions(VK_KHR_ROBUSTNESS_2_EXTENSION_NAME);
     AddOptionalExtensions(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME);
 
     RETURN_IF_SKIP(InitFramework());
 
-    if (IsExtensionsEnabled(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME)) {
-        VkPhysicalDeviceRobustness2FeaturesEXT robustness2_features = vku::InitStructHelper();
+    if (IsExtensionsEnabled(VK_KHR_ROBUSTNESS_2_EXTENSION_NAME) || IsExtensionsEnabled(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME)) {
+        VkPhysicalDeviceRobustness2FeaturesKHR robustness2_features = vku::InitStructHelper();
         GetPhysicalDeviceFeatures2(robustness2_features);
 
         if (robustness2_features.robustBufferAccess2) {
@@ -151,49 +154,48 @@ TEST_F(NegativeRobustness, DISABLED_PipelineRobustnessRobustBufferAccess2Unsuppo
     RETURN_IF_SKIP(InitState(nullptr, &features2));
 
     {
-        VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
+        VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
         CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
-        pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+        pipeline_robustness_info.storageBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
 
-        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-robustBufferAccess2-06931");
+        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-robustBufferAccess2-06931");
         pipe.CreateComputePipeline();
         m_errorMonitor->VerifyFound();
     }
 
     {
-        VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
+        VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
         CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
-        pipeline_robustness_info.uniformBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+        pipeline_robustness_info.uniformBuffers = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
 
-        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-robustBufferAccess2-06932");
+        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-robustBufferAccess2-06932");
         pipe.CreateComputePipeline();
         m_errorMonitor->VerifyFound();
     }
 
     {
-        VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
+        VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
         CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
-        pipeline_robustness_info.vertexInputs = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT;
+        pipeline_robustness_info.vertexInputs = VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2;
 
-        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-robustBufferAccess2-06933");
+        m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-robustBufferAccess2-06933");
         pipe.CreateComputePipeline();
         m_errorMonitor->VerifyFound();
     }
 }
 
-// Need to fix check to check if feature is exposed
-// TODO - https://github.com/KhronosGroup/Vulkan-ValidationLayers/issues/5657
-TEST_F(NegativeRobustness, DISABLED_PipelineRobustnessRobustImageAccess2Unsupported) {
+TEST_F(NegativeRobustness, PipelineRobustnessRobustImageAccess2Unsupported) {
     TEST_DESCRIPTION("Create a pipeline using VK_EXT_pipeline_robustness with robustImageAccess2 being unsupported");
 
     AddRequiredExtensions(VK_EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME);
+    AddOptionalExtensions(VK_KHR_ROBUSTNESS_2_EXTENSION_NAME);
     AddOptionalExtensions(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME);
 
     SetTargetApiVersion(VK_API_VERSION_1_1);
     RETURN_IF_SKIP(InitFramework());
 
-    if (IsExtensionsEnabled(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME)) {
-        VkPhysicalDeviceRobustness2FeaturesEXT robustness2_features = vku::InitStructHelper();
+    if (IsExtensionsEnabled(VK_KHR_ROBUSTNESS_2_EXTENSION_NAME) || IsExtensionsEnabled(VK_EXT_ROBUSTNESS_2_EXTENSION_NAME)) {
+        VkPhysicalDeviceRobustness2FeaturesKHR robustness2_features = vku::InitStructHelper();
         GetPhysicalDeviceFeatures2(robustness2_features);
 
         if (robustness2_features.robustImageAccess2) {
@@ -210,11 +212,11 @@ TEST_F(NegativeRobustness, DISABLED_PipelineRobustnessRobustImageAccess2Unsuppor
 
     RETURN_IF_SKIP(InitState(nullptr, &features2));
 
-    VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
+    VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
     CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
-    pipeline_robustness_info.images = VK_PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_2_EXT;
+    pipeline_robustness_info.images = VK_PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_2;
 
-    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-robustImageAccess2-06934");
+    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-robustImageAccess2-06934");
     pipe.CreateComputePipeline();
     m_errorMonitor->VerifyFound();
 }
@@ -224,25 +226,20 @@ TEST_F(NegativeRobustness, PipelineRobustnessRobustImageAccessNotExposed) {
 
     SetTargetApiVersion(VK_API_VERSION_1_2);
     AddRequiredExtensions(VK_EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME);
-    RETURN_IF_SKIP(InitFramework());
+    AddRequiredFeature(vkt::Feature::pipelineRobustness);
+    RETURN_IF_SKIP(Init());
     if (DeviceValidationVersion() > VK_API_VERSION_1_2) {
         GTEST_SKIP() << "version 1.3 enables extensions which we don't want";
     }
-    VkPhysicalDevicePipelineRobustnessFeaturesEXT pipeline_robustness_features = vku::InitStructHelper();
-    GetPhysicalDeviceFeatures2(pipeline_robustness_features);
-    if (!pipeline_robustness_features.pipelineRobustness) {
-        GTEST_SKIP() << "pipelineRobustness is not supported";
-    }
-    RETURN_IF_SKIP(InitState(nullptr, &pipeline_robustness_features));
-    if (DeviceExtensionSupported(gpu(), nullptr, VK_EXT_IMAGE_ROBUSTNESS_EXTENSION_NAME)) {
+    if (DeviceExtensionSupported(Gpu(), nullptr, VK_EXT_IMAGE_ROBUSTNESS_EXTENSION_NAME)) {
         GTEST_SKIP() << "VK_EXT_image_robustness is supported";
     }
 
-    VkPipelineRobustnessCreateInfoEXT pipeline_robustness_info = vku::InitStructHelper();
+    VkPipelineRobustnessCreateInfo pipeline_robustness_info = vku::InitStructHelper();
     CreateComputePipelineHelper pipe(*this, &pipeline_robustness_info);
-    pipeline_robustness_info.images = VK_PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_EXT;
+    pipeline_robustness_info.images = VK_PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS;
 
-    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfoEXT-robustImageAccess-06930");
+    m_errorMonitor->SetDesiredError("VUID-VkPipelineRobustnessCreateInfo-robustImageAccess-06930");
     pipe.CreateComputePipeline();
     m_errorMonitor->VerifyFound();
 }
