@@ -583,10 +583,9 @@ TEST_F(NegativeTransformFeedback, DrawIndirectByteCountEXT) {
     rp_info.pSubpasses = &subpass;
     rp_info.subpassCount = 1;
     vkt::RenderPass renderpass(test_device, rp_info);
-    ASSERT_TRUE(renderpass.handle());
 
-    VkShaderObj vs(this, kVertexMinimalGlsl, VK_SHADER_STAGE_VERTEX_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
-    VkShaderObj fs(this, kFragmentMinimalGlsl, VK_SHADER_STAGE_FRAGMENT_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
+    VkShaderObj vs(*m_device, kVertexMinimalGlsl, VK_SHADER_STAGE_VERTEX_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
+    VkShaderObj fs(*m_device, kFragmentMinimalGlsl, VK_SHADER_STAGE_FRAGMENT_BIT, SPV_ENV_VULKAN_1_0, SPV_SOURCE_GLSL_TRY);
     vs.InitFromGLSLTry(&test_device);
     fs.InitFromGLSLTry(&test_device);
 
@@ -649,7 +648,7 @@ TEST_F(NegativeTransformFeedback, RuntimeSpirv) {
     }
 
     {
-        std::stringstream vsSource;
+        std::ostringstream vsSource;
         vsSource << R"asm(
                OpCapability Shader
                OpCapability TransformFeedback
@@ -689,7 +688,7 @@ TEST_F(NegativeTransformFeedback, RuntimeSpirv) {
     }
 
     {
-        std::stringstream gsSource;
+        std::ostringstream gsSource;
         gsSource << R"asm(
                OpCapability Geometry
                OpCapability TransformFeedback
@@ -796,7 +795,7 @@ TEST_F(NegativeTransformFeedback, RuntimeSpirv) {
     }
 
     {
-        std::stringstream gsSource;
+        std::ostringstream gsSource;
         gsSource << R"asm(
                OpCapability Geometry
                OpCapability TransformFeedback
@@ -851,7 +850,7 @@ TEST_F(NegativeTransformFeedback, RuntimeSpirv) {
     }
 
     {
-        std::stringstream gsSource;
+        std::ostringstream gsSource;
         gsSource << R"asm(
                OpCapability Geometry
                OpCapability TransformFeedback
@@ -906,7 +905,7 @@ TEST_F(NegativeTransformFeedback, RuntimeSpirv) {
         uint32_t count = transform_feedback_props.maxTransformFeedbackStreamDataSize / offset + 1;
         // Limit to 25, because we are dynamically adding variables using letters as names
         if (count < 25) {
-            std::stringstream gsSource;
+            std::ostringstream gsSource;
             gsSource << R"asm(
                OpCapability Geometry
                OpCapability TransformFeedback
@@ -1092,7 +1091,7 @@ TEST_F(NegativeTransformFeedback, XfbExecutionModePipeline) {
     InitRenderTarget();
 
     auto vs = VkShaderObj::CreateFromASM(this, kXfbVsSource, VK_SHADER_STAGE_VERTEX_BIT);
-    VkShaderObj gs(this, kGeometryMinimalGlsl, VK_SHADER_STAGE_GEOMETRY_BIT);
+    VkShaderObj gs(*m_device, kGeometryMinimalGlsl, VK_SHADER_STAGE_GEOMETRY_BIT);
 
     CreatePipelineHelper pipe(*this);
     pipe.shader_stages_ = {vs.GetStageCreateInfo(), gs.GetStageCreateInfo(), pipe.fs_->GetStageCreateInfo()};
